# This R code reproduce all analyses pertaining to
# Ground cover and seedbed for the manuscript
# Interactive effects of spruce budworm and moose herbivory on balsam fir recruitment and regeneration

# Set your working directory
setwd("/XX/YY/ZZ")

##########################
## MULTIVARIATE ANALYSES
##########################
#To run this you need these below packages
install.packages("vegan")
library("vegan")
install.packages("MASS")
library("MASS")
install.packages("ecodist")
library("ecodist")

######
## 1998 - 2016 data, all ground cover species
######

#Importing your data
# Use the dataset in "Vegetation cover_Subplot_Exclosure experiment_TNNP_1998-2016.csv"
TNNP.sub.1998.2016 # Name used in this code file

# Select ground vegetation cover for species ≤ 2m in height for Matrix 1
M1.Species.subplot.1998.2016<-TNNP.sub.1998.2016[,c(8:45)]

# Select environmental variable for Matrix 2
M2.Species.subplot.1998.2016<-TNNP.sub.1998.2016[,c(1:7)]

#Check to make sure row names of Species and Env 
all.equal(rownames(M1.Species.subplot.1998.2016),rownames(M2.Species.subplot.1998.2016))

#Create a screeplot
dis <- vegdist(M1.Species.subplot.1998.2016, method = "bray")
scree<-nmds(dis, mindim = 1, maxdim = 5, nits = 10)
stress <- scree$stress
stress
plot(stress)
axis.seq <- c(seq(1, 1, length = 10), seq(2, 2, length = 10),
              seq(3, 3, length = 10), seq(4, 4, length = 10), seq(5, 5,
                                                                  length = 10))
plot(stress ~ factor(axis.seq))

#metaMDS
Species.subplot.1998.2016.mds<-metaMDS(M1.Species.subplot.1998.2016,dist="bray",k=2,trymax=1000,maxit=1000,
                                autotransform=F,trace=TRUE)
Species.subplot.1998.2016.mds

for(i in 1:500){
  Species.subplot.1998.2016.mds<-metaMDS(M1.Species.subplot.1998.2016,previous.best=Species.subplot.1998.2016.mds,dist="bray",
                                  k=2,autotransform=F)
}    

Species.subplot.1998.2016.mds

#Stress Plot and Goodness of fit
stressplot(Species.subplot.1998.2016.mds)

gof=goodness(Species.subplot.1998.2016.mds)
plot(Species.subplot.1998.2016.mds,type="t",main="Fig. Goodness of Fit*200")
points(Species.subplot.1998.2016.mds,display="sites",cex=gof*200)

#Comparisons with another NMDS calculator (isoMDS)
dis2<-vegdist(M1.Species.subplot.1998.2016)
Spe2.msd0<-isoMDS(dis2,k=2,trace=0)
pro2<-procrustes(Species.subplot.1998.2016.mds,Spe2.msd0)
pro2
plot(pro2)
plot(pro2,kind=2,main="Fig. Procrustes errors between monoMDS and isoMDS")

# Relationship of species to the NMDS axis
R<-cor(M1.Species.subplot.1998.2016, scores(Species.subplot.1998.2016.mds, display="sites"),use="everything",method="pearson")
R

###
# Graphic for NMDS by Year and Disturbance
# Figure 2a
###

ellipse<-ordiellipse(Species.subplot.1998.2016.mds,M2.Species.subplot.1998.2016$Time,draw="polygon",col="grey90",kind="se",
                     conf=0.95,label=F)
summary(ellipse)

opar <- par(mai=c(1.2,1.2,0.5,0.8))
Species.subplot.1998.2016.fig<-ordiplot(Species.subplot.1998.2016.mds,
                                 type="n",ylim=c(-0.2,0.3),xlim=c(-0.6,0.4))
ordiellipse(Species.subplot.1998.2016.mds,M2.Species.subplot.1998.2016$Time,draw="polygon",col="grey90",kind="se",
            conf=0.95,label=F)

arrows(summary(ellipse)[1,1],summary(ellipse)[2,1], 
       summary(ellipse)[1,2], summary(ellipse)[2,2],length=0.1,cex=5,lwd=2)
arrows(summary(ellipse)[1,2],summary(ellipse)[2,2], 
       summary(ellipse)[1,3], summary(ellipse)[2,3],length=0.1,cex=5,lwd=2)
arrows(summary(ellipse)[1,3],summary(ellipse)[2,3], 
       summary(ellipse)[1,4], summary(ellipse)[2,4],length=0.1,cex=5,lwd=2)

dataframe<-Species.subplot.1998.2016.mds$points[1:316,]
dataframe<-as.data.frame(dataframe)
class(dataframe)
dataframe<-cbind(M2.Species.subplot.1998.2016$Time, dataframe)
dataframe<-cbind(M2.Species.subplot.1998.2016$Disturbance, dataframe)
library(plyr)
dataframe<-rename(dataframe, c("M2.Species.subplot.1998.2016$Disturbance"="Disturbance", "M2.Species.subplot.1998.2016$Time"="Time"))
head(dataframe)
dataframe.1998<-subset(dataframe,Time=="0")
dataframe.2004<-subset(dataframe,Time=="6")
dataframe.2010<-subset(dataframe,Time=="12")
dataframe.2016<-subset(dataframe,Time=="18")

MDS1.1998<-tapply(dataframe.1998$MDS1, dataframe.1998$Disturbance,mean)
MDS2.1998<-tapply(dataframe.1998$MDS2, dataframe.1998$Disturbance,mean)
MDS1.2004<-tapply(dataframe.2004$MDS1, dataframe.2004$Disturbance,mean)
MDS2.2004<-tapply(dataframe.2004$MDS2, dataframe.2004$Disturbance,mean)
MDS1.2010<-tapply(dataframe.2010$MDS1, dataframe.2010$Disturbance,mean)
MDS2.2010<-tapply(dataframe.2010$MDS2, dataframe.2010$Disturbance,mean)
MDS1.2016<-tapply(dataframe.2016$MDS1, dataframe.2016$Disturbance,mean)
MDS2.2016<-tapply(dataframe.2016$MDS2, dataframe.2016$Disturbance,mean)

df.arrow<-cbind(MDS1.1998)
df.arrow<-cbind(MDS2.1998,df.arrow)
df.arrow<-cbind(MDS1.2004,df.arrow)
df.arrow<-cbind(MDS2.2004,df.arrow)
df.arrow<-cbind(MDS1.2010,df.arrow)
df.arrow<-cbind(MDS2.2010,df.arrow)
df.arrow<-cbind(MDS1.2016,df.arrow)
df.arrow<-cbind(MDS2.2016,df.arrow)

arrows(df.arrow[,8],df.arrow[,7],df.arrow[,6],df.arrow[,5],length=0.1,cex=5,lwd=2,col="grey50")
arrows(df.arrow[,6],df.arrow[,5],df.arrow[,4],df.arrow[,3],length=0.1,cex=5,lwd=2,col="grey50")
arrows(df.arrow[,4],df.arrow[,3],df.arrow[,2],df.arrow[,1],length=0.1,cex=5,lwd=2,col="grey50")

text(-0.52,0.09,"Young small gap",col="grey30")
text(-0.5,-0.25,"Mature",col="grey30")
text(-0.01,0.07,"Old small gap",col="grey30")
text(-0.21,-0.235,"Old large gap",col="grey30")
text(-0.31,-0.1,"1998")
text(0.11,0.1,"2016")

###
# Graphic for NMDS by Exclosure treatment
# Figure 2b
###

opar <- par(mai=c(1.2,1.2,0.5,0.8))
Species.subplot.1998.2016.fig<-ordiplot(Species.subplot.1998.2016.mds,
                                        type="n",ylim=c(-0.3,0.3),xlim=c(-0.3,0.3))

dataframe<-Species.subplot.1998.2016.mds$points[1:316,]
dataframe<-as.data.frame(dataframe)
class(dataframe)
dataframe<-cbind(M2.Species.subplot.1998.2016$Time, dataframe)
dataframe<-cbind(M2.Species.subplot.1998.2016$Treatment, dataframe)
dataframe<-cbind(M2.Species.subplot.1998.2016$Site, dataframe)
library(plyr)
dataframe<-rename(dataframe, c("M2.Species.subplot.1998.2016$Time"="Time", "M2.Species.subplot.1998.2016$Treatment"="Treatment", "M2.Species.subplot.1998.2016$Site"="Site"))
head(dataframe)
dataframe.CTL<-subset(dataframe,Treatment=="CTL")
dataframe.EX<-subset(dataframe,Treatment=="EX")

MDS1.CTL<-tapply(dataframe.CTL$MDS1, dataframe.CTL$Time,mean)
MDS2.CTL<-tapply(dataframe.CTL$MDS2, dataframe.CTL$Time,mean)
MDS1.EX<-tapply(dataframe.EX$MDS1, dataframe.EX$Time,mean)
MDS2.EX<-tapply(dataframe.EX$MDS2, dataframe.EX$Time,mean)

df.arrow<-cbind(MDS1.CTL)
df.arrow<-cbind(MDS2.CTL,df.arrow)
df.arrow<-cbind(MDS1.EX,df.arrow)
df.arrow<-cbind(MDS2.EX,df.arrow)

arrows(df.arrow[1,2],df.arrow[1,1],df.arrow[2,2],df.arrow[2,1],length=0.1,cex=5,lwd=2)
arrows(df.arrow[2,2],df.arrow[2,1],df.arrow[3,2],df.arrow[3,1],length=0.1,cex=5,lwd=2)
arrows(df.arrow[3,2],df.arrow[3,1],df.arrow[4,2],df.arrow[4,1],length=0.1,cex=5,lwd=2)
arrows(df.arrow[1,4],df.arrow[1,3],df.arrow[2,4],df.arrow[2,3],length=0.1,cex=5,lwd=2,col="grey50")
arrows(df.arrow[2,4],df.arrow[2,3],df.arrow[3,4],df.arrow[3,3],length=0.1,cex=5,lwd=2,col="grey50")
arrows(df.arrow[3,4],df.arrow[3,3],df.arrow[4,4],df.arrow[4,3],length=0.1,cex=5,lwd=2,col="grey50")
text(-0.34,-0.01,"Control")
text(-0.28,-0.13,"Exclosure")

#####
## Figure with functional groups difference between CTL and EX for years and disturbance
# Figure 6
#####

#Importing your data
# Use the dataset in "Functional Group Difference_Plot_Exclosure experiment_TNNP_1998-2016.csv"
ground.diff# Name used in this code file

all.1998<-subset(ground.diff,Year=="1998")
all.2016<-subset(ground.diff,Year=="2016")

par(mfrow=c(2,2),mar=c(5,2,1,3),bty="n")

# Young small gap

new.1998<-subset(all.1998,Disturbance=="new.insect")
new.1998.mean<-tapply(new.1998$Diff,new.1998$Functional.gr,mean)
new.1998.sd<-tapply(new.1998$Diff,new.1998$Functional.gr,sd)
new.1998.count<-tapply(new.1998$Diff,new.1998$Functional.gr,length)

new.2016<-subset(all.2016,Disturbance=="new.insect")
new.2016.mean<-tapply(new.2016$Diff,new.2016$Functional.gr,mean)
new.2016.sd<-tapply(new.2016$Diff,new.2016$Functional.gr,sd)
new.2016.count<-tapply(new.2016$Diff,new.2016$Functional.gr,length)

plot(new.1998.mean,pch=15,col="grey60",
     xaxt="n", yaxt="n",xlab="", ylim=c(-7,6))
arrows(x0=c(1:14),x1=c(1:14),y0=new.1998.mean+1.96*(new.1998.sd/sqrt(new.1998.count)),y1=new.1998.mean-1.96*(new.1998.sd/sqrt(new.1998.count)),code=3, length=0.08, angle=90,col="grey60")
points(new.2016.mean,pch=15,col="black")
arrows(x0=c(1:14),x1=c(1:14),y0=new.2016.mean+1.96*(new.2016.sd/sqrt(new.2016.count)),y1=new.2016.mean-1.96*(new.2016.sd/sqrt(new.2016.count)),code=3, length=0.08, angle=90)
abline (h=0,lty=3)
mtext("Young small gap",2, 0.5,cex=1.2)
axis(4)
axis(1,at=(1:14),las=3,
     labels=c("","","","","","","","","","","","","",""))

# Old large gap

oldL.1998<-subset(all.1998,Disturbance=="old.insect.L")
oldL.1998.mean<-tapply(oldL.1998$Diff,oldL.1998$Functional.gr,mean)
oldL.1998.sd<-tapply(oldL.1998$Diff,oldL.1998$Functional.gr,sd)
oldL.1998.count<-tapply(oldL.1998$Diff,oldL.1998$Functional.gr,length)

oldL.2016<-subset(all.2016,Disturbance=="old.insect.L")
oldL.2016.mean<-tapply(oldL.2016$Diff,oldL.2016$Functional.gr,mean)
oldL.2016.sd<-tapply(oldL.2016$Diff,oldL.2016$Functional.gr,sd)
oldL.2016.count<-tapply(oldL.2016$Diff,oldL.2016$Functional.gr,length)

plot(oldL.1998.mean,pch=15,col="grey60",
     xaxt="n",yaxt="n", xlab="", ylim=c(-5,6))
arrows(x0=c(1:14),x1=c(1:14),y0=oldL.1998.mean+1.96*(oldL.1998.sd/sqrt(oldL.1998.count)),y1=oldL.1998.mean-1.96*(oldL.1998.sd/sqrt(oldL.1998.count)),code=3, length=0.08, angle=90,col="grey60")
points(oldL.2016.mean,pch=15,col="black")
arrows(x0=c(1:14),x1=c(1:14),y0=oldL.2016.mean+1.96*(oldL.2016.sd/sqrt(oldL.2016.count)),y1=oldL.2016.mean-1.96*(oldL.2016.sd/sqrt(oldL.2016.count)),code=3, length=0.08, angle=90)
abline (h=0,lty=3)
mtext("Old large gap",2, 0.5,cex=1.2)
axis(4)
axis(1,at=(1:14),las=3,
     labels=c("","","","","","","","","","","","","",""))

# Mature

mature.1998<-subset(all.1998,Disturbance=="mature")
mature.1998.mean<-tapply(mature.1998$Diff,mature.1998$Functional.gr,mean)
mature.1998.sd<-tapply(mature.1998$Diff,mature.1998$Functional.gr,sd)
mature.1998.count<-tapply(mature.1998$Diff,mature.1998$Functional.gr,length)

mature.2016<-subset(all.2016,Disturbance=="mature")
mature.2016.mean<-tapply(mature.2016$Diff,mature.2016$Functional.gr,mean)
mature.2016.sd<-tapply(mature.2016$Diff,mature.2016$Functional.gr,sd)
mature.2016.count<-tapply(mature.2016$Diff,mature.2016$Functional.gr,length)

plot(mature.1998.mean,pch=15,col="grey60",
     xaxt="n",yaxt="n", xlab="", ylim=c(-4,8))
arrows(x0=c(1:14),x1=c(1:14),y0=mature.1998.mean+1.96*(mature.1998.sd/sqrt(mature.1998.count)),y1=mature.1998.mean-1.96*(mature.1998.sd/sqrt(mature.1998.count)),code=3, length=0.08, angle=90,col="grey60")
points(mature.2016.mean,pch=15,col="black")
arrows(x0=c(1:14),x1=c(1:14),y0=mature.2016.mean+1.96*(mature.2016.sd/sqrt(mature.2016.count)),y1=mature.2016.mean-1.96*(mature.2016.sd/sqrt(mature.2016.count)),code=3, length=0.08, angle=90)
abline (h=0,lty=3)
mtext("Mature",2, 0.5,cex=1.2)
axis(4)
axis(1,at=(1:14),las=3,
     labels=c("lichen","fungi","bryophyte","fern",
              "grass","orchid", "non native","early forb",
              "late forb","S shrub", "M shrub","T shrub",
              "deciduous","conifer"))

# Old small gap

oldM.1998<-subset(all.1998,Disturbance=="old.insect.M")
oldM.1998.mean<-tapply(oldM.1998$Diff,oldM.1998$Functional.gr,mean)
oldM.1998.sd<-tapply(oldM.1998$Diff,oldM.1998$Functional.gr,sd)
oldM.1998.count<-tapply(oldM.1998$Diff,oldM.1998$Functional.gr,length)

oldM.2016<-subset(all.2016,Disturbance=="old.insect.M")
oldM.2016.mean<-tapply(oldM.2016$Diff,oldM.2016$Functional.gr,mean)
oldM.2016.sd<-tapply(oldM.2016$Diff,oldM.2016$Functional.gr,sd)
oldM.2016.count<-tapply(oldM.2016$Diff,oldM.2016$Functional.gr,length)

plot(oldM.1998.mean,pch=15,col="grey60",
     xaxt="n",yaxt="n", xlab="", ylim=c(-5,8))
arrows(x0=c(1:14),x1=c(1:14),y0=oldM.1998.mean+1.96*(oldM.1998.sd/sqrt(oldM.1998.count)),y1=oldM.1998.mean-1.96*(oldM.1998.sd/sqrt(oldM.1998.count)),code=3, length=0.08, angle=90,col="grey60")
points(oldM.2016.mean,pch=15,col="black")
arrows(x0=c(1:14),x1=c(1:14),y0=oldM.2016.mean+1.96*(oldM.2016.sd/sqrt(oldM.2016.count)),y1=oldM.2016.mean-1.96*(oldM.2016.sd/sqrt(oldM.2016.count)),code=3, length=0.08, angle=90)
abline (h=0,lty=3)
mtext("Old small gap",2, 0.5,cex=1.2)
axis(4)
axis(1,at=(1:14),las=3,
     labels=c("lichen","fungi","bryophyte","fern",
              "grass","orchid", "non native","early forb",
              "late forb","S shrub", "M shrub","T shrub",
              "deciduous","conifer"))

###
# Graph bryophyte - Treatment
# Figure A3
###

mean.bry.Trt<-tapply(TNNP.sub.1998.2016$Bry.sp,list(TNNP.sub.1998.2016$Site,TNNP.sub.1998.2016$Year,TNNP.sub.1998.2016$Treatment),mean,na.rm=T)
sd.bry.Trt<-tapply(TNNP.sub.1998.2016$Bry.sp,list(TNNP.sub.1998.2016$Site,TNNP.sub.1998.2016$Year,TNNP.sub.1998.2016$Treatment),sd,na.rm=T)
length.bry.Trt<-tapply(TNNP.sub.1998.2016$Bry.sp,list(TNNP.sub.1998.2016$Site,TNNP.sub.1998.2016$Year,TNNP.sub.1998.2016$Treatment),length)

par(mfrow=c(2,4),mar=c(5,2,2,1),bty="n")

plot(x=c(1:4),y=mean.bry.Trt[4,,1],xaxt="n", xlab="",cex.axis=1.2, ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[4,,1]+1.96*(sd.bry.Trt[4,,1]/sqrt(length.bry.Trt[4,,1])),y1=mean.bry.Trt[4,,1]-1.96*(sd.bry.Trt[4,,1]/sqrt(length.bry.Trt[4,,1])),code=3, length=0.08, angle=90,col="grey60")
points((x=c(1:4)),mean.bry.Trt[4,,2],xaxt="n", xlab="",pch = 17,ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[4,,2]+1.96*(sd.bry.Trt[4,,2]/sqrt(length.bry.Trt[4,,2])),y1=mean.bry.Trt[4,,2]-1.96*(sd.bry.Trt[4,,2]/sqrt(length.bry.Trt[4,,2])),code=3, length=0.08, angle=90)
axis(1,at=(1:4),las=2,cex.axis=1.2,labels=c(1998,2004,2010,2016))
mtext(side=1,line=3.7,cex=0.9,"Hall's Beach")
mtext(side=3,line=0.5,"Mature")

plot(x=c(1:4),y=mean.bry.Trt[7,,1],xaxt="n", xlab="",cex.axis=1.2, ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[7,,1]+1.96*(sd.bry.Trt[7,,1]/sqrt(length.bry.Trt[7,,1])),y1=mean.bry.Trt[7,,1]-1.96*(sd.bry.Trt[7,,1]/sqrt(length.bry.Trt[7,,1])),code=3, length=0.08, angle=90,col="grey60")
points((x=c(1:4)),mean.bry.Trt[7,,2],xaxt="n", xlab="",yaxt="n",pch = 17, ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[7,,2]+1.96*(sd.bry.Trt[7,,2]/sqrt(length.bry.Trt[7,,2])),y1=mean.bry.Trt[7,,2]-1.96*(sd.bry.Trt[7,,2]/sqrt(length.bry.Trt[7,,2])),code=3, length=0.08, angle=90)
axis(1,at=(1:4),las=2,cex.axis=1.2,labels=c(1998,2004,2010,2016))
mtext(side=1,line=3.7,cex=0.9,"Outport Trail")

plot(x=c(1:4),y=mean.bry.Trt[5,,1],xaxt="n", xlab="",cex.axis=1.2, ylim=c(0,110))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[5,,1]+1.96*(sd.bry.Trt[5,,1]/sqrt(length.bry.Trt[5,,1])),y1=mean.bry.Trt[5,,1]-1.96*(sd.bry.Trt[5,,1]/sqrt(length.bry.Trt[5,,1])),code=3, length=0.08, angle=90,col="grey60")
points((x=c(1:4)),mean.bry.Trt[5,,2],xaxt="n", xlab="",yaxt="n",pch = 17,ylim=c(0,110))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[5,,2]+1.96*(sd.bry.Trt[5,,2]/sqrt(length.bry.Trt[5,,2])),y1=mean.bry.Trt[5,,2]-1.96*(sd.bry.Trt[5,,2]/sqrt(length.bry.Trt[5,,2])),code=3, length=0.08, angle=90)
axis(1,at=(1:4),las=2,cex.axis=1.2,labels=c(1998,2004,2010,2016))
mtext(side=1,line=3.7,cex=0.9,"Minchin's Cove")
mtext(side=3,line=0.5,"Young small gap")

plot(x=c(1:4),y=mean.bry.Trt[8,,1],xaxt="n", xlab="",cex.axis=1.2, ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[8,,1]+1.96*(sd.bry.Trt[8,,1]/sqrt(length.bry.Trt[8,,1])),y1=mean.bry.Trt[8,,1]-1.96*(sd.bry.Trt[8,,1]/sqrt(length.bry.Trt[8,,1])),code=3, length=0.08, angle=90,col="grey60")
points((x=c(1:4)),mean.bry.Trt[8,,2],xaxt="n", xlab="",yaxt="n",pch=17,ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[8,,2]+1.96*(sd.bry.Trt[8,,2]/sqrt(length.bry.Trt[8,,2])),y1=mean.bry.Trt[8,,2]-1.96*(sd.bry.Trt[8,,2]/sqrt(length.bry.Trt[8,,2])),code=3, length=0.08, angle=90)
axis(1,at=(1:4),las=2,cex.axis=1.2,labels=c(1998,2004,2010,2016))
mtext(side=1,line=3.7,cex=0.9,"Platter's Cove")

plot(x=c(1:4),y=mean.bry.Trt[1,,1],xaxt="n", xlab="",cex.axis=1.2, ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[1,,1]+1.96*(sd.bry.Trt[1,,1]/sqrt(length.bry.Trt[1,,1])),y1=mean.bry.Trt[1,,1]-1.96*(sd.bry.Trt[1,,1]/sqrt(length.bry.Trt[1,,1])),code=3, length=0.08, angle=90,col="grey60")
points((x=c(1:4)),mean.bry.Trt[1,,2],xaxt="n", xlab="",yaxt="n",pch=17,ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[1,,2]+1.96*(sd.bry.Trt[1,,2]/sqrt(length.bry.Trt[1,,2])),y1=mean.bry.Trt[1,,2]-1.96*(sd.bry.Trt[1,,2]/sqrt(length.bry.Trt[1,,2])),code=3, length=0.08, angle=90)
axis(1,at=(1:4),las=2,cex.axis=1.2,labels=c(1998,2004,2010,2016))
mtext(side=1,line=3.7,cex=0.9,"Bread Cove")
mtext(side=3,line=0.5,"Old small gap")

plot(x=c(1:4),y=mean.bry.Trt[6,,1],xaxt="n", xlab="",cex.axis=1.2, ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[6,,1]+1.96*(sd.bry.Trt[6,,1]/sqrt(length.bry.Trt[6,,1])),y1=mean.bry.Trt[6,,1]-1.96*(sd.bry.Trt[6,,1]/sqrt(length.bry.Trt[6,,1])),code=3, length=0.08, angle=90,col="grey60")
points((x=c(1:4)),mean.bry.Trt[6,,2],xaxt="n", xlab="",yaxt="n",pch=17,ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[6,,2]+1.96*(sd.bry.Trt[6,,2]/sqrt(length.bry.Trt[6,,2])),y1=mean.bry.Trt[6,,2]-1.96*(sd.bry.Trt[6,,2]/sqrt(length.bry.Trt[6,,2])),code=3, length=0.08, angle=90)
axis(1,at=(1:4),las=2,cex.axis=1.2,labels=c(1998,2004,2010,2016))
mtext(side=1,line=3.7,cex=0.9,"Ochre Hill")

plot(x=c(1:4),y=mean.bry.Trt[2,,1],xaxt="n", xlab="", ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[2,,1]+1.96*(sd.bry.Trt[2,,1]/sqrt(length.bry.Trt[2,,1])),y1=mean.bry.Trt[2,,1]-1.96*(sd.bry.Trt[2,,1]/sqrt(length.bry.Trt[2,,1])),code=3, length=0.08, angle=90,col="grey60")
points((x=c(1:4)),mean.bry.Trt[2,,1],xaxt="n", xlab="",pch=17,ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[2,,1]+1.96*(sd.bry.Trt[2,,1]/sqrt(length.bry.Trt[2,,1])),y1=mean.bry.Trt[2,,1]-1.96*(sd.bry.Trt[2,,1]/sqrt(length.bry.Trt[2,,1])),code=3, length=0.08, angle=90)
axis(1,at=(1:4),las=2,cex.axis=1.2,labels=c(1998,2004,2010,2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Centre")
mtext(side=3,line=0.5,"Old large gap")

plot(x=c(1:4),y=mean.bry.Trt[3,,1],xaxt="n", xlab="",cex.axis=1.2, ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[3,,1]+1.96*(sd.bry.Trt[3,,1]/sqrt(length.bry.Trt[3,,1])),y1=mean.bry.Trt[3,,1]-1.96*(sd.bry.Trt[3,,1]/sqrt(length.bry.Trt[3,,1])),code=3, length=0.08, angle=90,col="grey60")
points((x=c(1:4)),mean.bry.Trt[3,,2],xaxt="n", xlab="",yaxt="n",pch=17,ylim=c(0,100))
arrows(x0=c(1:4),x1=c(1:4),y0=mean.bry.Trt[3,,2]+1.96*(sd.bry.Trt[3,,2]/sqrt(length.bry.Trt[3,,2])),y1=mean.bry.Trt[3,,2]-1.96*(sd.bry.Trt[3,,2]/sqrt(length.bry.Trt[3,,2])),code=3, length=0.08, angle=90)
axis(1,at=(1:4),las=2,cex.axis=1.2,labels=c(1998,2004,2010,2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Edge")
