# This R code reproduce all analyses pertaining to
# Balsam fir life stages height and density for the manuscript
# Interactive effects of spruce budworm and moose herbivory on balsam fir recruitment and regeneration

# Set your working directory
setwd("/XX/YY/ZZ")

##########################
## GRAPHICAL MODELS
##########################

# Import your data 
# Use the dataset in "bF Density_Exclosure experiment_TNNP_1998-2016.csv"
bF.TNNP # Name used for density data in this code file

# Use the dataset in "bF Height_Exclosure experiment_TNNP_1998-2016.csv"
bF.TNNP.ht # Name used for Height data in this code file

bF.TNNP.ht.seedling<-subset(bF.TNNP.ht,bF.height<30|is.na(bF.height))

bF.TNNP.ht.sapling<-subset(bF.TNNP.ht,bF.height>30&bF.height<200|is.na(bF.height))

###
# Graph bF seed density
# Figure A2
###

mean.seed<-tapply(bF.TNNP$bF.seed.density,list(bF.TNNP$Site,bF.TNNP$Year),mean,na.rm=T)

par(mfrow=c(2,4),mar=c(5,2,2,1),bty="n")

plot(mean.seed[4,],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,800),xlim=c(5,19))
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Hall's Beach")
mtext(side=3,line=0.5,"Mature")

plot(mean.seed[7,],xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,800),xlim=c(5,19))
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Outport Trail")

plot(mean.seed[5,],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,800),xlim=c(5,19))
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Minchin's Cove")
mtext(side=3,line=0.5,"Young small gap")

plot(mean.seed[8,],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,800),xlim=c(5,19))
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Platter's Cove")

plot(mean.seed[1,],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,800),xlim=c(5,19))
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Bread Cove")
mtext(side=3,line=0.5,"Old small gap")

plot(mean.seed[6,],xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,800),xlim=c(5,19))
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Ochre Hill")

plot(mean.seed[2,],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,800),xlim=c(5,19))
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Centre")
mtext(side=3,line=0.5,"Old large gap")

plot(mean.seed[3,],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,800),xlim=c(5,19))
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Edge")

###
# Graph bF seedling density - Treatment
# Figure 3
###

mean.sdl.den<-tapply(bF.TNNP$bF.seedling.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),mean,na.rm=T)
sd.sdl.den<-tapply(bF.TNNP$bF.seedling.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),sd,na.rm=T)
length.sdl.den<-tapply(bF.TNNP$bF.seedling.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),length)

par(mfrow=c(2,4),mar=c(5,2,2,1),bty="n")

plot(mean.sdl.den[4,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[4,,1]+1.96*(sd.sdl.den[4,,1]/sqrt(length.sdl.den[4,,1])),y1=mean.sdl.den[4,,1]-1.96*(sd.sdl.den[4,,1]/sqrt(length.sdl.den[4,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.den[4,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[4,,2]+1.96*(sd.sdl.den[4,,2]/sqrt(length.sdl.den[4,,2])),y1=mean.sdl.den[4,,2]-1.96*(sd.sdl.den[4,,2]/sqrt(length.sdl.den[4,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Hall's Beach")
mtext(side=3,line=0.5,"Mature")

plot(mean.sdl.den[7,,1],xaxt="n", xlab="", cex.axis=1.2, ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[7,,1]+1.96*(sd.sdl.den[7,,1]/sqrt(length.sdl.den[7,,1])),y1=mean.sdl.den[7,,1]-1.96*(sd.sdl.den[7,,1]/sqrt(length.sdl.den[7,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.den[7,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[7,,2]+1.96*(sd.sdl.den[7,,2]/sqrt(length.sdl.den[7,,2])),y1=mean.sdl.den[7,,2]-1.96*(sd.sdl.den[7,,2]/sqrt(length.sdl.den[7,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Outport Trail")

plot(mean.sdl.den[5,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[5,,1]+1.96*(sd.sdl.den[5,,1]/sqrt(length.sdl.den[5,,1])),y1=mean.sdl.den[5,,1]-1.96*(sd.sdl.den[5,,1]/sqrt(length.sdl.den[5,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.den[5,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[5,,2]+1.96*(sd.sdl.den[5,,2]/sqrt(length.sdl.den[5,,2])),y1=mean.sdl.den[5,,2]-1.96*(sd.sdl.den[5,,2]/sqrt(length.sdl.den[5,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Minchin's Cove")
mtext(side=3,line=0.5,"Young small gap")

plot(mean.sdl.den[8,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[8,,1]+1.96*(sd.sdl.den[8,,1]/sqrt(length.sdl.den[8,,1])),y1=mean.sdl.den[8,,1]-1.96*(sd.sdl.den[8,,1]/sqrt(length.sdl.den[8,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.den[8,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[8,,2]+1.96*(sd.sdl.den[8,,2]/sqrt(length.sdl.den[8,,2])),y1=mean.sdl.den[8,,2]-1.96*(sd.sdl.den[8,,2]/sqrt(length.sdl.den[8,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Platter's Cove")

plot(mean.sdl.den[1,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[1,,1]+1.96*(sd.sdl.den[1,,1]/sqrt(length.sdl.den[1,,1])),y1=mean.sdl.den[1,,1]-1.96*(sd.sdl.den[1,,1]/sqrt(length.sdl.den[1,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.den[1,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[1,,2]+1.96*(sd.sdl.den[1,,2]/sqrt(length.sdl.den[1,,2])),y1=mean.sdl.den[1,,2]-1.96*(sd.sdl.den[1,,2]/sqrt(length.sdl.den[1,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Bread Cove")
mtext(side=3,line=0.5,"Old small gap")

plot(mean.sdl.den[6,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[6,,1]+1.96*(sd.sdl.den[6,,1]/sqrt(length.sdl.den[6,,1])),y1=mean.sdl.den[6,,1]-1.96*(sd.sdl.den[6,,1]/sqrt(length.sdl.den[6,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.den[6,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[6,,2]+1.96*(sd.sdl.den[6,,2]/sqrt(length.sdl.den[6,,2])),y1=mean.sdl.den[6,,2]-1.96*(sd.sdl.den[6,,2]/sqrt(length.sdl.den[6,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Ochre Hill")

plot(mean.sdl.den[2,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[2,,1]+1.96*(sd.sdl.den[2,,1]/sqrt(length.sdl.den[2,,1])),y1=mean.sdl.den[2,,1]-1.96*(sd.sdl.den[2,,1]/sqrt(length.sdl.den[2,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.den[2,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[2,,2]+1.96*(sd.sdl.den[2,,2]/sqrt(length.sdl.den[2,,2])),y1=mean.sdl.den[2,,2]-1.96*(sd.sdl.den[2,,2]/sqrt(length.sdl.den[2,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Centre")
mtext(side=3,line=0.5,"Old large gap")

plot(mean.sdl.den[3,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[3,,1]+1.96*(sd.sdl.den[3,,1]/sqrt(length.sdl.den[3,,1])),y1=mean.sdl.den[3,,1]-1.96*(sd.sdl.den[3,,1]/sqrt(length.sdl.den[3,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.den[3,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.den[3,,2]+1.96*(sd.sdl.den[3,,2]/sqrt(length.sdl.den[3,,2])),y1=mean.sdl.den[3,,2]-1.96*(sd.sdl.den[3,,2]/sqrt(length.sdl.den[3,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Edge")

###
# Graph bF seedling height - Treatment
# Figure A4
###

mean.sdl.ht<-tapply(bF.TNNP.ht.seedling$bF.height,list(bF.TNNP.ht.seedling$Site,bF.TNNP.ht.seedling$Year,bF.TNNP.ht.seedling$Treatment),mean,na.rm=T)
sd.sdl.ht<-tapply(bF.TNNP.ht.seedling$bF.height,list(bF.TNNP.ht.seedling$Site,bF.TNNP.ht.seedling$Year,bF.TNNP.ht.seedling$Treatment),sd,na.rm=T)
length.sdl.ht<-tapply(bF.TNNP.ht.seedling$bF.height,list(bF.TNNP.ht.seedling$Site,bF.TNNP.ht.seedling$Year,bF.TNNP.ht.seedling$Treatment),length)

par(mfrow=c(2,4),mar=c(5,2,2,1),bty="n")

plot(mean.sdl.ht[4,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[4,,1]+1.96*(sd.sdl.ht[4,,1]/sqrt(length.sdl.ht[4,,1])),y1=mean.sdl.ht[4,,1]-1.96*(sd.sdl.ht[4,,1]/sqrt(length.sdl.ht[4,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.ht[4,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[4,,2]+1.96*(sd.sdl.ht[4,,2]/sqrt(length.sdl.ht[4,,2])),y1=mean.sdl.ht[4,,2]-1.96*(sd.sdl.ht[4,,2]/sqrt(length.sdl.ht[4,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2, cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Hall's Beach")
mtext(side=3,line=0.5,"Mature")

plot(mean.sdl.ht[7,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[7,,1]+1.96*(sd.sdl.ht[7,,1]/sqrt(length.sdl.ht[7,,1])),y1=mean.sdl.ht[7,,1]-1.96*(sd.sdl.ht[7,,1]/sqrt(length.sdl.ht[7,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.ht[7,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[7,,2]+1.96*(sd.sdl.ht[7,,2]/sqrt(length.sdl.ht[7,,2])),y1=mean.sdl.ht[7,,2]-1.96*(sd.sdl.ht[7,,2]/sqrt(length.sdl.ht[7,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2, cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Outport Trail")

plot(mean.sdl.ht[5,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[5,,1]+1.96*(sd.sdl.ht[5,,1]/sqrt(length.sdl.ht[5,,1])),y1=mean.sdl.ht[5,,1]-1.96*(sd.sdl.ht[5,,1]/sqrt(length.sdl.ht[5,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.ht[5,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[5,,2]+1.96*(sd.sdl.ht[5,,2]/sqrt(length.sdl.ht[5,,2])),y1=mean.sdl.ht[5,,2]-1.96*(sd.sdl.ht[5,,2]/sqrt(length.sdl.ht[5,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2, cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Minchin's Cove")
mtext(side=3,line=0.5,"Young small gap")

plot(mean.sdl.ht[8,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[8,,1]+1.96*(sd.sdl.ht[8,,1]/sqrt(length.sdl.ht[8,,1])),y1=mean.sdl.ht[8,,1]-1.96*(sd.sdl.ht[8,,1]/sqrt(length.sdl.ht[8,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.ht[8,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[8,,2]+1.96*(sd.sdl.ht[8,,2]/sqrt(length.sdl.ht[8,,2])),y1=mean.sdl.ht[8,,2]-1.96*(sd.sdl.ht[8,,2]/sqrt(length.sdl.ht[8,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2, cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Platter's Cove")

plot(mean.sdl.ht[1,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[1,,1]+1.96*(sd.sdl.ht[1,,1]/sqrt(length.sdl.ht[1,,1])),y1=mean.sdl.ht[1,,1]-1.96*(sd.sdl.ht[1,,1]/sqrt(length.sdl.ht[1,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.ht[1,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[1,,2]+1.96*(sd.sdl.ht[1,,2]/sqrt(length.sdl.ht[1,,2])),y1=mean.sdl.ht[1,,2]-1.96*(sd.sdl.ht[1,,2]/sqrt(length.sdl.ht[1,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2, cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Bread Cove")
mtext(side=3,line=0.5,"Old small gap")

plot(mean.sdl.ht[6,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[6,,1]+1.96*(sd.sdl.ht[6,,1]/sqrt(length.sdl.ht[6,,1])),y1=mean.sdl.ht[6,,1]-1.96*(sd.sdl.ht[6,,1]/sqrt(length.sdl.ht[6,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.ht[6,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[6,,2]+1.96*(sd.sdl.ht[6,,2]/sqrt(length.sdl.ht[6,,2])),y1=mean.sdl.ht[6,,2]-1.96*(sd.sdl.ht[6,,2]/sqrt(length.sdl.ht[6,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2, cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Ochre Hill")

plot(mean.sdl.ht[2,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[2,,1]+1.96*(sd.sdl.ht[2,,1]/sqrt(length.sdl.ht[2,,1])),y1=mean.sdl.ht[2,,1]-1.96*(sd.sdl.ht[2,,1]/sqrt(length.sdl.ht[2,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.ht[2,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[2,,2]+1.96*(sd.sdl.ht[2,,2]/sqrt(length.sdl.ht[2,,2])),y1=mean.sdl.ht[2,,2]-1.96*(sd.sdl.ht[2,,2]/sqrt(length.sdl.ht[2,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2, cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Centre")
mtext(side=3,line=0.5,"Old large gap")

plot(mean.sdl.ht[3,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[3,,1]+1.96*(sd.sdl.ht[3,,1]/sqrt(length.sdl.ht[3,,1])),y1=mean.sdl.ht[3,,1]-1.96*(sd.sdl.ht[3,,1]/sqrt(length.sdl.ht[3,,1])),code=3, length=0.01, angle=90)
points(mean.sdl.ht[3,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,30))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.sdl.ht[3,,2]+1.96*(sd.sdl.ht[3,,2]/sqrt(length.sdl.ht[3,,2])),y1=mean.sdl.ht[3,,2]-1.96*(sd.sdl.ht[3,,2]/sqrt(length.sdl.ht[3,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2, cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Edge")

###
# Graph bF sapling density - Treatment
# Figure A5
###

mean.spl.den<-tapply(bF.TNNP$bF.sapling.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),mean,na.rm=T)
sd.spl.den<-tapply(bF.TNNP$bF.sapling.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),sd,na.rm=T)
length.spl.den<-tapply(bF.TNNP$bF.sapling.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),length)

par(mfrow=c(2,4),mar=c(5,2,2,1),bty="n")

plot(mean.spl.den[4,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,4.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[4,,1]+1.96*(sd.spl.den[4,,1]/sqrt(length.spl.den[4,,1])),y1=mean.spl.den[4,,1]-1.96*(sd.spl.den[4,,1]/sqrt(length.spl.den[4,,1])),code=3, length=0.01, angle=90)
points(mean.spl.den[4,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,5))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[4,,2]+1.96*(sd.spl.den[4,,2]/sqrt(length.spl.den[4,,2])),y1=mean.spl.den[4,,2]-1.96*(sd.spl.den[4,,2]/sqrt(length.spl.den[4,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Hall's Beach")
mtext(side=3,line=0.5,"Mature")

plot(mean.spl.den[7,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,4))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[7,,1]+1.96*(sd.spl.den[7,,1]/sqrt(length.spl.den[7,,1])),y1=mean.spl.den[7,,1]-1.96*(sd.spl.den[7,,1]/sqrt(length.spl.den[7,,1])),code=3, length=0.01, angle=90)
points(mean.spl.den[7,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,5))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[7,,2]+1.96*(sd.spl.den[7,,2]/sqrt(length.spl.den[7,,2])),y1=mean.spl.den[7,,2]-1.96*(sd.spl.den[7,,2]/sqrt(length.spl.den[7,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Outport Trail")

plot(mean.spl.den[5,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,4))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[5,,1]+1.96*(sd.spl.den[5,,1]/sqrt(length.spl.den[5,,1])),y1=mean.spl.den[5,,1]-1.96*(sd.spl.den[5,,1]/sqrt(length.spl.den[5,,1])),code=3, length=0.01, angle=90)
points(mean.spl.den[5,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,5))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[5,,2]+1.96*(sd.spl.den[5,,2]/sqrt(length.spl.den[5,,2])),y1=mean.spl.den[5,,2]-1.96*(sd.spl.den[5,,2]/sqrt(length.spl.den[5,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Minchin's Cove")
mtext(side=3,line=0.5,"Young small gap")

plot(mean.spl.den[8,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,4))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[8,,1]+1.96*(sd.spl.den[8,,1]/sqrt(length.spl.den[8,,1])),y1=mean.spl.den[8,,1]-1.96*(sd.spl.den[8,,1]/sqrt(length.spl.den[8,,1])),code=3, length=0.01, angle=90)
points(mean.spl.den[8,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,5))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[8,,2]+1.96*(sd.spl.den[8,,2]/sqrt(length.spl.den[8,,2])),y1=mean.spl.den[8,,2]-1.96*(sd.spl.den[8,,2]/sqrt(length.spl.den[8,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Platter's Cove")

plot(mean.spl.den[1,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,4))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[1,,1]+1.96*(sd.spl.den[1,,1]/sqrt(length.spl.den[1,,1])),y1=mean.spl.den[1,,1]-1.96*(sd.spl.den[1,,1]/sqrt(length.spl.den[1,,1])),code=3, length=0.01, angle=90)
points(mean.spl.den[1,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,5))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[1,,2]+1.96*(sd.spl.den[1,,2]/sqrt(length.spl.den[1,,2])),y1=mean.spl.den[1,,2]-1.96*(sd.spl.den[1,,2]/sqrt(length.spl.den[1,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Bread Cove")
mtext(side=3,line=0.5,"Old small gap")

plot(mean.spl.den[6,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,4))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[6,,1]+1.96*(sd.spl.den[6,,1]/sqrt(length.spl.den[6,,1])),y1=mean.spl.den[6,,1]-1.96*(sd.spl.den[6,,1]/sqrt(length.spl.den[6,,1])),code=3, length=0.01, angle=90)
points(mean.spl.den[6,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,5))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[6,,2]+1.96*(sd.spl.den[6,,2]/sqrt(length.spl.den[6,,2])),y1=mean.spl.den[6,,2]-1.96*(sd.spl.den[6,,2]/sqrt(length.spl.den[6,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Ochre Hill")

plot(mean.spl.den[2,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,4))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[2,,1]+1.96*(sd.spl.den[2,,1]/sqrt(length.spl.den[2,,1])),y1=mean.spl.den[2,,1]-1.96*(sd.spl.den[2,,1]/sqrt(length.spl.den[2,,1])),code=3, length=0.01, angle=90)
points(mean.spl.den[2,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,5))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[2,,2]+1.96*(sd.spl.den[2,,2]/sqrt(length.spl.den[2,,2])),y1=mean.spl.den[2,,2]-1.96*(sd.spl.den[2,,2]/sqrt(length.spl.den[2,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Centre")
mtext(side=3,line=0.5,"Old large gap")

plot(mean.spl.den[3,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,4))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[3,,1]+1.96*(sd.spl.den[3,,1]/sqrt(length.spl.den[3,,1])),y1=mean.spl.den[3,,1]-1.96*(sd.spl.den[3,,1]/sqrt(length.spl.den[3,,1])),code=3, length=0.01, angle=90)
points(mean.spl.den[3,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,5))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.den[3,,2]+1.96*(sd.spl.den[3,,2]/sqrt(length.spl.den[3,,2])),y1=mean.spl.den[3,,2]-1.96*(sd.spl.den[3,,2]/sqrt(length.spl.den[3,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Edge")

###
# Graph bF sapling height - Treatment
# Figure 4
###

mean.spl.ht<-tapply(bF.TNNP.ht.sapling$bF.height,list(bF.TNNP.ht.sapling$Site,bF.TNNP.ht.sapling$Year,bF.TNNP.ht.sapling$Treatment),mean,na.rm=T)
sd.spl.ht<-tapply(bF.TNNP.ht.sapling$bF.height,list(bF.TNNP.ht.sapling$Site,bF.TNNP.ht.sapling$Year,bF.TNNP.ht.sapling$Treatment),sd,na.rm=T)
length.spl.ht<-tapply(bF.TNNP.ht.sapling$bF.height,list(bF.TNNP.ht.sapling$Site,bF.TNNP.ht.sapling$Year,bF.TNNP.ht.sapling$Treatment),length)

par(mfrow=c(2,4),mar=c(5,2,2,1),bty="n")

plot(mean.spl.ht[4,,1],xaxt="n", xlab="",cex.axis=1.2, ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[4,,1]+1.96*(sd.spl.ht[4,,1]/sqrt(length.spl.ht[4,,1])),y1=mean.spl.ht[4,,1]-1.96*(sd.spl.ht[4,,1]/sqrt(length.spl.ht[4,,1])),code=3, length=0.01, angle=90)
points(mean.spl.ht[4,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[4,,2]+1.96*(sd.spl.ht[4,,2]/sqrt(length.spl.ht[4,,2])),y1=mean.spl.ht[4,,2]-1.96*(sd.spl.ht[4,,2]/sqrt(length.spl.ht[4,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Hall's Beach")
mtext(side=3,line=0.5,"Mature")

plot(mean.spl.ht[7,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[7,,1]+1.96*(sd.spl.ht[7,,1]/sqrt(length.spl.ht[7,,1])),y1=mean.spl.ht[7,,1]-1.96*(sd.spl.ht[7,,1]/sqrt(length.spl.ht[7,,1])),code=3, length=0.01, angle=90)
points(mean.spl.ht[7,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[7,,2]+1.96*(sd.spl.ht[7,,2]/sqrt(length.spl.ht[7,,2])),y1=mean.spl.ht[7,,2]-1.96*(sd.spl.ht[7,,2]/sqrt(length.spl.ht[7,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Outport Trail")

plot(mean.spl.ht[5,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[5,,1]+1.96*(sd.spl.ht[5,,1]/sqrt(length.spl.ht[5,,1])),y1=mean.spl.ht[5,,1]-1.96*(sd.spl.ht[5,,1]/sqrt(length.spl.ht[5,,1])),code=3, length=0.01, angle=90)
points(mean.spl.ht[5,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[5,,2]+1.96*(sd.spl.ht[5,,2]/sqrt(length.spl.ht[5,,2])),y1=mean.spl.ht[5,,2]-1.96*(sd.spl.ht[5,,2]/sqrt(length.spl.ht[5,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Minchin's Cove")
mtext(side=3,line=0.5,"Young small gap")

plot(mean.spl.ht[8,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[8,,1]+1.96*(sd.spl.ht[8,,1]/sqrt(length.spl.ht[8,,1])),y1=mean.spl.ht[8,,1]-1.96*(sd.spl.ht[8,,1]/sqrt(length.spl.ht[8,,1])),code=3, length=0.01, angle=90)
points(mean.spl.ht[8,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[8,,2]+1.96*(sd.spl.ht[8,,2]/sqrt(length.spl.ht[8,,2])),y1=mean.spl.ht[8,,2]-1.96*(sd.spl.ht[8,,2]/sqrt(length.spl.ht[8,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Platter's Cove")

plot(mean.spl.ht[1,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[1,,1]+1.96*(sd.spl.ht[1,,1]/sqrt(length.spl.ht[1,,1])),y1=mean.spl.ht[1,,1]-1.96*(sd.spl.ht[1,,1]/sqrt(length.spl.ht[1,,1])),code=3, length=0.01, angle=90)
points(mean.spl.ht[1,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[1,,2]+1.96*(sd.spl.ht[1,,2]/sqrt(length.spl.ht[1,,2])),y1=mean.spl.ht[1,,2]-1.96*(sd.spl.ht[1,,2]/sqrt(length.spl.ht[1,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Bread Cove")
mtext(side=3,line=0.5,"Old small gap")

plot(mean.spl.ht[6,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[6,,1]+1.96*(sd.spl.ht[6,,1]/sqrt(length.spl.ht[6,,1])),y1=mean.spl.ht[6,,1]-1.96*(sd.spl.ht[6,,1]/sqrt(length.spl.ht[6,,1])),code=3, length=0.01, angle=90)
points(mean.spl.ht[6,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[6,,2]+1.96*(sd.spl.ht[6,,2]/sqrt(length.spl.ht[6,,2])),y1=mean.spl.ht[6,,2]-1.96*(sd.spl.ht[6,,2]/sqrt(length.spl.ht[6,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Ochre Hill")

plot(mean.spl.ht[2,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,160))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[2,,1]+1.96*(sd.spl.ht[2,,1]/sqrt(length.spl.ht[2,,1])),y1=mean.spl.ht[2,,1]-1.96*(sd.spl.ht[2,,1]/sqrt(length.spl.ht[2,,1])),code=3, length=0.01, angle=90)
points(mean.spl.ht[2,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[2,,2]+1.96*(sd.spl.ht[2,,2]/sqrt(length.spl.ht[2,,2])),y1=mean.spl.ht[2,,2]-1.96*(sd.spl.ht[2,,2]/sqrt(length.spl.ht[2,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Centre")
mtext(side=3,line=0.5,"Old large gap")

plot(mean.spl.ht[3,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,170))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[3,,1]+1.96*(sd.spl.ht[3,,1]/sqrt(length.spl.ht[3,,1])),y1=mean.spl.ht[3,,1]-1.96*(sd.spl.ht[3,,1]/sqrt(length.spl.ht[3,,1])),code=3, length=0.01, angle=90)
points(mean.spl.ht[3,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,150))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.spl.ht[3,,2]+1.96*(sd.spl.ht[3,,2]/sqrt(length.spl.ht[3,,2])),y1=mean.spl.ht[3,,2]-1.96*(sd.spl.ht[3,,2]/sqrt(length.spl.ht[3,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Edge")

###
# Graph bF adult density - Treatment
# Figure A6
###

mean.adu.den<-tapply(bF.TNNP$bF.adult.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),mean,na.rm=T)
sd.adu.den<-tapply(bF.TNNP$bF.adult.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),sd,na.rm=T)
length.adu.den<-tapply(bF.TNNP$bF.adult.density,list(bF.TNNP$Site,bF.TNNP$Year,bF.TNNP$Treatment),length)

par(mfrow=c(2,4),mar=c(5,2,2,1),bty="n")

plot(mean.adu.den[4,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,0.15))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[4,,1]+1.96*(sd.adu.den[4,,1]/sqrt(length.adu.den[4,,1])),y1=mean.adu.den[4,,1]-1.96*(sd.adu.den[4,,1]/sqrt(length.adu.den[4,,1])),code=3, length=0.01, angle=90)
points(mean.adu.den[4,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,0.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[4,,2]+1.96*(sd.adu.den[4,,2]/sqrt(length.adu.den[4,,2])),y1=mean.adu.den[4,,2]-1.96*(sd.adu.den[4,,2]/sqrt(length.adu.den[4,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Hall's Beach")
mtext(side=3,line=0.5,"Mature")

plot(mean.adu.den[7,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,0.15))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[7,,1]+1.96*(sd.adu.den[7,,1]/sqrt(length.adu.den[7,,1])),y1=mean.adu.den[7,,1]-1.96*(sd.adu.den[7,,1]/sqrt(length.adu.den[7,,1])),code=3, length=0.01, angle=90)
points(mean.adu.den[7,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,0.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[7,,2]+1.96*(sd.adu.den[7,,2]/sqrt(length.adu.den[7,,2])),y1=mean.adu.den[7,,2]-1.96*(sd.adu.den[7,,2]/sqrt(length.adu.den[7,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Outport Trail")

plot(mean.adu.den[5,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,0.15))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[5,,1]+1.96*(sd.adu.den[5,,1]/sqrt(length.adu.den[5,,1])),y1=mean.adu.den[5,,1]-1.96*(sd.adu.den[5,,1]/sqrt(length.adu.den[5,,1])),code=3, length=0.01, angle=90)
points(mean.adu.den[5,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,0.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[5,,2]+1.96*(sd.adu.den[5,,2]/sqrt(length.adu.den[5,,2])),y1=mean.adu.den[5,,2]-1.96*(sd.adu.den[5,,2]/sqrt(length.adu.den[5,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Minchin's Cove")
mtext(side=3,line=0.5,"Young small gap")

plot(mean.adu.den[8,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,0.15))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[8,,1]+1.96*(sd.adu.den[8,,1]/sqrt(length.adu.den[8,,1])),y1=mean.adu.den[8,,1]-1.96*(sd.adu.den[8,,1]/sqrt(length.adu.den[8,,1])),code=3, length=0.01, angle=90)
points(mean.adu.den[8,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,0.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[8,,2]+1.96*(sd.adu.den[8,,2]/sqrt(length.adu.den[8,,2])),y1=mean.adu.den[8,,2]-1.96*(sd.adu.den[8,,2]/sqrt(length.adu.den[8,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Platter's Cove")

plot(mean.adu.den[1,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,0.15))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[1,,1]+1.96*(sd.adu.den[1,,1]/sqrt(length.adu.den[1,,1])),y1=mean.adu.den[1,,1]-1.96*(sd.adu.den[1,,1]/sqrt(length.adu.den[1,,1])),code=3, length=0.01, angle=90)
points(mean.adu.den[1,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,0.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[1,,2]+1.96*(sd.adu.den[1,,2]/sqrt(length.adu.den[1,,2])),y1=mean.adu.den[1,,2]-1.96*(sd.adu.den[1,,2]/sqrt(length.adu.den[1,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Bread Cove")
mtext(side=3,line=0.5,"Old small gap")

plot(mean.adu.den[6,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,0.15))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[6,,1]+1.96*(sd.adu.den[6,,1]/sqrt(length.adu.den[6,,1])),y1=mean.adu.den[6,,1]-1.96*(sd.adu.den[6,,1]/sqrt(length.adu.den[6,,1])),code=3, length=0.01, angle=90)
points(mean.adu.den[6,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,0.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[6,,2]+1.96*(sd.adu.den[6,,2]/sqrt(length.adu.den[6,,2])),y1=mean.adu.den[6,,2]-1.96*(sd.adu.den[6,,2]/sqrt(length.adu.den[6,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Ochre Hill")

plot(mean.adu.den[2,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,0.15))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[2,,1]+1.96*(sd.adu.den[2,,1]/sqrt(length.adu.den[2,,1])),y1=mean.adu.den[2,,1]-1.96*(sd.adu.den[2,,1]/sqrt(length.adu.den[2,,1])),code=3, length=0.01, angle=90)
points(mean.adu.den[2,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,0.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[2,,2]+1.96*(sd.adu.den[2,,2]/sqrt(length.adu.den[2,,2])),y1=mean.adu.den[2,,2]-1.96*(sd.adu.den[2,,2]/sqrt(length.adu.den[2,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Centre")
mtext(side=3,line=0.5,"Old large gap")

plot(mean.adu.den[3,,1],xaxt="n", xlab="", cex.axis=1.2,ylim=c(0,0.15))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[3,,1]+1.96*(sd.adu.den[3,,1]/sqrt(length.adu.den[3,,1])),y1=mean.adu.den[3,,1]-1.96*(sd.adu.den[3,,1]/sqrt(length.adu.den[3,,1])),code=3, length=0.01, angle=90)
points(mean.adu.den[3,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,0.2))
arrows(x0=c(1:19),x1=c(1:19),y0=mean.adu.den[3,,2]+1.96*(sd.adu.den[3,,2]/sqrt(length.adu.den[3,,2])),y1=mean.adu.den[3,,2]-1.96*(sd.adu.den[3,,2]/sqrt(length.adu.den[3,,2])),code=3, length=0.01, angle=90)
axis(1,at=(1:19),las=2,cex.axis=1.2,labels=c(1998,"",2000,"",2002,"",2004,
                                "",2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Edge")

##########################
## UNIVARIATE ANALYSES
##########################
#To run this you need these below packages
install.packages("lme4")
library("lme4")
library(lattice)#To calculate correlation matrix
library(bbmle)
library(AICcmodavg)
library(MuMIn)

########################
# ANALYSIS ON SINGLE DISTURBANCE
########################

# Mature Data
bF.TNNP.mature<-subset(bF.TNNP,Site=="HAL"|Site=="OUT")

# Young small gap Data
bF.TNNP.new<-subset(bF.TNNP,Site=="MIN"|Site=="PLC")

# Old small gap Data
bF.TNNP.old.M<-subset(bF.TNNP,Site=="BCB"|Site=="OCH")

# Old large gap Data
bF.TNNP.old.L<-subset(bF.TNNP,Site=="BHC"|Site=="BHE")

#########
# AICc selection of bF seedling density models - MATURE
#########

# Check assumptions
Seedling.mat <- lmer(log(bF.seedling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)
res.seedling.mat<-resid(Seedling.mat)
fit.seedling.mat<-fitted(Seedling.mat)
plot(fit.seedling.mat,res.seedling.mat)
lag.plot(res.seedling.mat,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.seedling.mat)
qqline(res.seedling.mat)
#############

Seedling <- list( )
Seedling[[1]] <- lmer(log(bF.seedling.density+0.01) ~ (1|Site), data=bF.TNNP.mature, REML=FALSE)
Seedling[[2]] <- lmer(log(bF.seedling.density+0.01) ~ Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)
Seedling[[3]] <- lmer(log(bF.seedling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)

##create a vector of names to trace back models in set
Seedling.names <- c("NULL","T","Trt*T")

##generate AICc table
print(aictab(cand.set = Seedling, modnames = Seedling.names,sort = TRUE),
      digits = 3, LL = TRUE)

output.seedling<-matrix(nrow=3,ncol=2)
rownames(output.seedling)<-c("NULL","T","Trt*T");
colnames(output.seedling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Seedling[[1]])
Rsq2<-r.squaredGLMM(Seedling[[2]])
Rsq3<-r.squaredGLMM(Seedling[[3]])

## Marginal R^2
output.seedling[1,1]<-Rsq1[1]
output.seedling[2,1]<-Rsq2[1]
output.seedling[3,1]<-Rsq3[1]

## Conditional R^2
output.seedling[1,2]<-Rsq1[2]
output.seedling[2,2]<-Rsq2[2]
output.seedling[3,2]<-Rsq3[2]

output.seedling

#########
# AICc selection of bF seedling density models - Young small gap
#########

# Check assumptions
Seedling.new <- lmer(log(bF.seedling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.new, REML=FALSE)
res.seedling.new<-resid(Seedling.new)
fit.seedling.new<-fitted(Seedling.new)
plot(fit.seedling.new,res.seedling.new)
lag.plot(res.seedling.new,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.seedling.new)
qqline(res.seedling.new)
#############

Seedling <- list( )
Seedling[[1]] <- lmer(log(bF.seedling.density+0.01) ~ (1|Site), data=bF.TNNP.new, REML=FALSE)
Seedling[[2]] <- lmer(log(bF.seedling.density+0.01) ~ Treatment + (1|Site), data=bF.TNNP.new, REML=FALSE)
Seedling[[3]] <- lmer(log(bF.seedling.density+0.01) ~ Time + (1|Site), data=bF.TNNP.new, REML=FALSE)
Seedling[[4]] <- lmer(log(bF.seedling.density+0.01) ~ Treatment + Time + (1|Site), data=bF.TNNP.new, REML=FALSE)

##create a vector of names to trace back models in set
Seedling.names <- c("NULL","Trt", "T", "Trt+T")

##generate AICc table
print(aictab(cand.set = Seedling, modnames = Seedling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.seedling<-matrix(nrow=4,ncol=2)
rownames(output.seedling)<-c("NULL","Trt", "T", "Trt+T");
colnames(output.seedling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Seedling[[1]])
Rsq2<-r.squaredGLMM(Seedling[[2]])
Rsq3<-r.squaredGLMM(Seedling[[3]])
Rsq4<-r.squaredGLMM(Seedling[[4]])

## Marginal R^2
output.seedling[1,1]<-Rsq1[1]
output.seedling[2,1]<-Rsq2[1]
output.seedling[3,1]<-Rsq3[1]
output.seedling[4,1]<-Rsq4[1]

## Conditional R^2
output.seedling[1,2]<-Rsq1[2]
output.seedling[2,2]<-Rsq2[2]
output.seedling[3,2]<-Rsq3[2]
output.seedling[4,2]<-Rsq4[2]

output.seedling

#########
# AICc selection of bF seedling density models - Old small gap
#########

# Check assumptions
Seedling.old.M <- lmer(log(bF.seedling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)
res.seedling.old.M<-resid(Seedling.old.M)
fit.seedling.old.M<-fitted(Seedling.old.M)
plot(fit.seedling.old.M,res.seedling.old.M)
lag.plot(res.seedling.old.M,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.seedling.old.M)
qqline(res.seedling.old.M)
#############

Seedling <- list( )
Seedling[[1]] <- lmer(log(bF.seedling.density+0.01) ~ (1|Site), data=bF.TNNP.old.M, REML=FALSE)
Seedling[[2]] <- lmer(log(bF.seedling.density+0.01) ~ Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)

##create a vector of names to trace back models in set
Seedling.names <- c("NULL","T")

##generate AICc table
print(aictab(cand.set = Seedling, modnames = Seedling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.seedling<-matrix(nrow=2,ncol=2)
rownames(output.seedling)<-c("NULL","T");
colnames(output.seedling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Seedling[[1]])
Rsq2<-r.squaredGLMM(Seedling[[2]])

## Marginal R^2
output.seedling[1,1]<-Rsq1[1]
output.seedling[2,1]<-Rsq2[1]

## Conditional R^2
output.seedling[1,2]<-Rsq1[2]
output.seedling[2,2]<-Rsq2[2]

output.seedling

#########
# AICc selection of bF seedling density models - Old large gap
#########

# Check assumptions
Seedling.old.L <- lmer(log(bF.seedling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.L, REML=FALSE)
res.seedling.old.L<-resid(Seedling.old.L)
fit.seedling.old.L<-fitted(Seedling.old.L)
plot(fit.seedling.old.L,res.seedling.old.L)
lag.plot(res.seedling.old.L,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.seedling.old.L)
qqline(res.seedling.old.L)
#############

Seedling <- list( )
Seedling[[1]] <- lmer(log(bF.seedling.density+0.01) ~ (1|Site), data=bF.TNNP.old.L, REML=FALSE)
Seedling[[2]] <- lmer(log(bF.seedling.density+0.01) ~ Treatment + (1|Site), data=bF.TNNP.old.L, REML=FALSE)
Seedling[[3]] <- lmer(log(bF.seedling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.L, REML=FALSE)

##create a vector of names to trace back models in set
Seedling.names <- c("NULL","Trt","Trt*T")

##generate AICc table
print(aictab(cand.set = Seedling, modnames = Seedling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.seedling<-matrix(nrow=3,ncol=2)
rownames(output.seedling)<-c("NULL","Trt","Trt*T");
colnames(output.seedling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Seedling[[1]])
Rsq2<-r.squaredGLMM(Seedling[[2]])
Rsq3<-r.squaredGLMM(Seedling[[3]])

## Marginal R^2
output.seedling[1,1]<-Rsq1[1]
output.seedling[2,1]<-Rsq2[1]
output.seedling[3,1]<-Rsq3[1]

## Conditional R^2
output.seedling[1,2]<-Rsq1[2]
output.seedling[2,2]<-Rsq2[2]
output.seedling[3,2]<-Rsq3[2]

output.seedling

#############################

# Mature Data
bF.TNNP.ht.mature<-subset(bF.TNNP.ht,Site=="HAL"|Site=="OUT")

# Young small gap Data
bF.TNNP.ht.new<-subset(bF.TNNP.ht,Site=="MIN"|Site=="PLC")

# Old small gap Data
bF.TNNP.ht.old.M<-subset(bF.TNNP.ht,Site=="BCB"|Site=="OCH")

# Old large gap Data
bF.TNNP.ht.old.L<-subset(bF.TNNP.ht,Site=="BHC"|Site=="BHE")

#########
# AICc selection of bF seedling height models - MATURE
#########

## Subset data for Seedling height in mature forest
bF.TNNP.ht.mat.seedling<-subset(bF.TNNP.ht.mature,bF.height<30|is.na(bF.height))

# Check assumptions
Seedling.ht.mat <- lmer(bF.height ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.ht.mat.seedling, REML=FALSE)
res.seedling.ht.mat<-resid(Seedling.ht.mat)
fit.seedling.ht.mat<-fitted(Seedling.ht.mat)
plot(fit.seedling.ht.mat,res.seedling.ht.mat)
lag.plot(res.seedling.ht.mat,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.seedling.ht.mat)
qqline(res.seedling.ht.mat)
#############

Seedling <- list( )
Seedling[[1]] <- lmer(bF.height ~ (1|Site), data=bF.TNNP.ht.mat.seedling, REML=FALSE)
Seedling[[2]] <- lmer(bF.height ~ Treatment + (1|Site), data=bF.TNNP.ht.mat.seedling, REML=FALSE)
Seedling[[3]] <- lmer(bF.height ~ Time + (1|Site), data=bF.TNNP.ht.mat.seedling, REML=FALSE)
Seedling[[4]] <- lmer(bF.height ~ Treatment + Time + (1|Site), data=bF.TNNP.ht.mat.seedling, REML=FALSE)
Seedling[[5]] <- lmer(bF.height ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.ht.mat.seedling, REML=FALSE)

##create a vector of names to trace back models in set
Seedling.names <- c("NULL","Trt", "T", "Trt+T", "Trt*T")

##generate AICc table
print(aictab(cand.set = Seedling, modnames = Seedling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.seedling<-matrix(nrow=5,ncol=2)
rownames(output.seedling)<-c("NULL","Trt", "T", "Trt+T", "Trt*T");
colnames(output.seedling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Seedling[[1]])
Rsq2<-r.squaredGLMM(Seedling[[2]])
Rsq3<-r.squaredGLMM(Seedling[[3]])
Rsq4<-r.squaredGLMM(Seedling[[4]])
Rsq5<-r.squaredGLMM(Seedling[[5]])

## Marginal R^2
output.seedling[1,1]<-Rsq1[1]
output.seedling[2,1]<-Rsq2[1]
output.seedling[3,1]<-Rsq3[1]
output.seedling[4,1]<-Rsq4[1]
output.seedling[5,1]<-Rsq5[1]

## Conditional R^2
output.seedling[1,2]<-Rsq1[2]
output.seedling[2,2]<-Rsq2[2]
output.seedling[3,2]<-Rsq3[2]
output.seedling[4,2]<-Rsq4[2]
output.seedling[5,2]<-Rsq5[2]

output.seedling

#########
# AICc selection of bF seedling height models - Young small gap
#########

## Subset data for Seedling height in Young small gap
bF.TNNP.ht.new.seedling<-subset(bF.TNNP.ht.new,bF.height<30|is.na(bF.height))

# Check assumptions
Seedling.ht.new <- lmer(bF.height ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.ht.new.seedling, REML=FALSE)
res.seedling.ht.new<-resid(Seedling.ht.new)
fit.seedling.ht.new<-fitted(Seedling.ht.new)
plot(fit.seedling.ht.new,res.seedling.ht.new)
lag.plot(res.seedling.ht.new,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.seedling.ht.new)
qqline(res.seedling.ht.new)
#############

Seedling <- list( )
Seedling[[1]] <- lmer(bF.height ~ (1|Site), data=bF.TNNP.ht.new.seedling, REML=FALSE)
Seedling[[2]] <- lmer(bF.height ~ Treatment + (1|Site), data=bF.TNNP.ht.new.seedling, REML=FALSE)
Seedling[[3]] <- lmer(bF.height ~ Time + (1|Site), data=bF.TNNP.ht.new.seedling, REML=FALSE)
Seedling[[4]] <- lmer(bF.height ~ Treatment + Time + (1|Site), data=bF.TNNP.ht.new.seedling, REML=FALSE)

##create a vector of names to trace back models in set
Seedling.names <- c("NULL","Trt", "T", "Trt+T")

##generate AICc table
print(aictab(cand.set = Seedling, modnames = Seedling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.seedling<-matrix(nrow=4,ncol=2)
rownames(output.seedling)<-c("NULL","Trt", "T", "Trt+T");
colnames(output.seedling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Seedling[[1]])
Rsq2<-r.squaredGLMM(Seedling[[2]])
Rsq3<-r.squaredGLMM(Seedling[[3]])
Rsq4<-r.squaredGLMM(Seedling[[4]])

## Marginal R^2
output.seedling[1,1]<-Rsq1[1]
output.seedling[2,1]<-Rsq2[1]
output.seedling[3,1]<-Rsq3[1]
output.seedling[4,1]<-Rsq4[1]

## Conditional R^2
output.seedling[1,2]<-Rsq1[2]
output.seedling[2,2]<-Rsq2[2]
output.seedling[3,2]<-Rsq3[2]
output.seedling[4,2]<-Rsq4[2]

output.seedling

#########
# AICc selection of bF seedling height models - Old small gap
#########

## Subset data for Seedling height in Old small gap
bF.TNNP.ht.old.M.seedling<-subset(bF.TNNP.ht.old.M,bF.height<30|is.na(bF.height))

# Check assumptions
Seedling.ht.old.M <- lmer(bF.height ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.ht.old.M.seedling, REML=FALSE)
res.seedling.ht.old.M<-resid(Seedling.ht.old.M)
fit.seedling.ht.old.M<-fitted(Seedling.ht.old.M)
plot(fit.seedling.ht.old.M,res.seedling.ht.old.M)
lag.plot(res.seedling.ht.old.M,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.seedling.ht.old.M)
qqline(res.seedling.ht.old.M)
#############

Seedling <- list( )
Seedling[[1]] <- lmer(bF.height ~ (1|Site), data=bF.TNNP.ht.old.M.seedling, REML=FALSE)
Seedling[[2]] <- lmer(bF.height ~ Treatment + (1|Site), data=bF.TNNP.ht.old.M.seedling, REML=FALSE)
Seedling[[3]] <- lmer(bF.height ~ Time + (1|Site), data=bF.TNNP.ht.old.M.seedling, REML=FALSE)
Seedling[[4]] <- lmer(bF.height ~ Treatment + Time + (1|Site), data=bF.TNNP.ht.old.M.seedling, REML=FALSE)
Seedling[[5]] <- lmer(bF.height ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.ht.old.M.seedling, REML=FALSE)

##create a vector of names to trace back models in set
Seedling.names <- c("NULL","Trt", "T", "Trt+T", "Trt*T")

##generate AICc table
print(aictab(cand.set = Seedling, modnames = Seedling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.seedling<-matrix(nrow=5,ncol=2)
rownames(output.seedling)<-c("NULL","Trt", "T", "Trt+T", "Trt*T");
colnames(output.seedling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Seedling[[1]])
Rsq2<-r.squaredGLMM(Seedling[[2]])
Rsq3<-r.squaredGLMM(Seedling[[3]])
Rsq4<-r.squaredGLMM(Seedling[[4]])
Rsq5<-r.squaredGLMM(Seedling[[5]])

## Marginal R^2
output.seedling[1,1]<-Rsq1[1]
output.seedling[2,1]<-Rsq2[1]
output.seedling[3,1]<-Rsq3[1]
output.seedling[4,1]<-Rsq4[1]
output.seedling[5,1]<-Rsq5[1]

## Conditional R^2
output.seedling[1,2]<-Rsq1[2]
output.seedling[2,2]<-Rsq2[2]
output.seedling[3,2]<-Rsq3[2]
output.seedling[4,2]<-Rsq4[2]
output.seedling[5,2]<-Rsq5[2]

output.seedling

#########
# AICc selection of bF seedling height models - Old large gap
#########

## Subset data for Seedling height in Old large gap
bF.TNNP.ht.old.L.seedling<-subset(bF.TNNP.ht.old.L,bF.height<30|is.na(bF.height))

# Check assumptions
Seedling.ht.old.L <- lmer(bF.height ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.ht.old.L.seedling, REML=FALSE)
res.seedling.ht.old.L<-resid(Seedling.ht.old.L)
fit.seedling.ht.old.L<-fitted(Seedling.ht.old.L)
plot(fit.seedling.ht.old.L,res.seedling.ht.old.L)
lag.plot(res.seedling.ht.old.L,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.seedling.ht.old.L)
qqline(res.seedling.ht.old.L)
#############

Seedling <- list( )
Seedling[[1]] <- lmer(bF.height ~ (1|Site), data=bF.TNNP.ht.old.L.seedling, REML=FALSE)
summary(Seedling[[1]])

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Seedling[[1]])
Rsq1

#########
# AICc selection of bF sapling density models - MATURE
#########

# Check assumptions
Sapling.mat <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)
res.sapling.mat<-resid(Sapling.mat)
fit.sapling.mat<-fitted(Sapling.mat)
plot(fit.sapling.mat,res.sapling.mat)
lag.plot(res.sapling.mat,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.sapling.mat)
qqline(res.sapling.mat)
#############

Sapling <- list( )
Sapling[[1]] <- lmer(log(bF.sapling.density+0.01) ~ (1|Site), data=bF.TNNP.mature, REML=FALSE)
Sapling[[2]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + (1|Site), data=bF.TNNP.mature, REML=FALSE)
Sapling[[3]] <- lmer(log(bF.sapling.density+0.01) ~ Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)
Sapling[[4]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)
Sapling[[5]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)

##create a vector of names to trace back models in set
Sapling.names <- c("NULL","Trt", "T", "Trt+T", "Trt*T")

##generate AICc table
print(aictab(cand.set = Sapling, modnames = Sapling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.sapling<-matrix(nrow=5,ncol=2)
rownames(output.sapling)<-c("NULL","Trt", "T", "Trt+T", "Trt*T");
colnames(output.sapling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Sapling[[1]])
Rsq2<-r.squaredGLMM(Sapling[[2]])
Rsq3<-r.squaredGLMM(Sapling[[3]])
Rsq4<-r.squaredGLMM(Sapling[[4]])
Rsq5<-r.squaredGLMM(Sapling[[5]])

## Marginal R^2
output.sapling[1,1]<-Rsq1[1]
output.sapling[2,1]<-Rsq2[1]
output.sapling[3,1]<-Rsq3[1]
output.sapling[4,1]<-Rsq4[1]
output.sapling[5,1]<-Rsq5[1]

## Conditional R^2
output.sapling[1,2]<-Rsq1[2]
output.sapling[2,2]<-Rsq2[2]
output.sapling[3,2]<-Rsq3[2]
output.sapling[4,2]<-Rsq4[2]
output.sapling[5,2]<-Rsq5[2]

output.sapling

#########
# AICc selection of bF sapling density models - Young small gap
#########

# Check assumptions
Sapling.new <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.new, REML=FALSE)
res.sapling.new<-resid(Sapling.new)
fit.sapling.new<-fitted(Sapling.new)
plot(fit.sapling.new,res.sapling.new)
lag.plot(res.sapling.new,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.sapling.new)
qqline(res.sapling.new)
#############

Sapling <- list( )
Sapling[[1]] <- lmer(log(bF.sapling.density+0.01) ~ (1|Site), data=bF.TNNP.new, REML=FALSE)
Sapling[[2]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + (1|Site), data=bF.TNNP.new, REML=FALSE)
Sapling[[3]] <- lmer(log(bF.sapling.density+0.01) ~ Time + (1|Site), data=bF.TNNP.new, REML=FALSE)
Sapling[[4]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + (1|Site), data=bF.TNNP.new, REML=FALSE)
Sapling[[5]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.new, REML=FALSE)

##create a vector of names to trace back models in set
Sapling.names <- c("NULL","Trt", "T", "Trt+T", "Trt*T")

##generate AICc table
print(aictab(cand.set = Sapling, modnames = Sapling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.sapling<-matrix(nrow=5,ncol=2)
rownames(output.sapling)<-c("NULL","Trt", "T", "Trt+T", "Trt*T");
colnames(output.sapling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Sapling[[1]])
Rsq2<-r.squaredGLMM(Sapling[[2]])
Rsq3<-r.squaredGLMM(Sapling[[3]])
Rsq4<-r.squaredGLMM(Sapling[[4]])
Rsq5<-r.squaredGLMM(Sapling[[5]])

## Marginal R^2
output.sapling[1,1]<-Rsq1[1]
output.sapling[2,1]<-Rsq2[1]
output.sapling[3,1]<-Rsq3[1]
output.sapling[4,1]<-Rsq4[1]
output.sapling[5,1]<-Rsq5[1]

## Conditional R^2
output.sapling[1,2]<-Rsq1[2]
output.sapling[2,2]<-Rsq2[2]
output.sapling[3,2]<-Rsq3[2]
output.sapling[4,2]<-Rsq4[2]
output.sapling[5,2]<-Rsq5[2]

output.sapling

#########
# AICc selection of bF sapling density models - Old small gap
#########

# Check assumptions
Sapling.old.M <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)
res.sapling.old.M<-resid(Sapling.old.M)
fit.sapling.old.M<-fitted(Sapling.old.M)
plot(fit.sapling.old.M,res.sapling.old.M)
lag.plot(res.sapling.old.M,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.sapling.old.M)
qqline(res.sapling.old.M)
#############

Sapling <- list( )
Sapling[[1]] <- lmer(log(bF.sapling.density+0.01) ~ (1|Site), data=bF.TNNP.old.M, REML=FALSE)
Sapling[[2]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + (1|Site), data=bF.TNNP.old.M, REML=FALSE)
Sapling[[3]] <- lmer(log(bF.sapling.density+0.01) ~ Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)
Sapling[[4]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)
Sapling[[5]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)

##create a vector of names to trace back models in set
Sapling.names <- c("NULL","Trt", "T", "Trt+T", "Trt*T")

##generate AICc table
print(aictab(cand.set = Sapling, modnames = Sapling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.sapling<-matrix(nrow=5,ncol=2)
rownames(output.sapling)<-c("NULL","Trt", "T", "Trt+T", "Trt*T");
colnames(output.sapling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Sapling[[1]])
Rsq2<-r.squaredGLMM(Sapling[[2]])
Rsq3<-r.squaredGLMM(Sapling[[3]])
Rsq4<-r.squaredGLMM(Sapling[[4]])
Rsq5<-r.squaredGLMM(Sapling[[5]])

## Marginal R^2
output.sapling[1,1]<-Rsq1[1]
output.sapling[2,1]<-Rsq2[1]
output.sapling[3,1]<-Rsq3[1]
output.sapling[4,1]<-Rsq4[1]
output.sapling[5,1]<-Rsq5[1]

## Conditional R^2
output.sapling[1,2]<-Rsq1[2]
output.sapling[2,2]<-Rsq2[2]
output.sapling[3,2]<-Rsq3[2]
output.sapling[4,2]<-Rsq4[2]
output.sapling[5,2]<-Rsq5[2]

output.sapling

#########
# AICc selection of bF sapling density models - Old large gap
#########

# Check assumptions
Sapling.old.L <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.L, REML=FALSE)
res.sapling.old.L<-resid(Sapling.old.L)
fit.sapling.old.L<-fitted(Sapling.old.L)
plot(fit.sapling.old.L,res.sapling.old.L)
lag.plot(res.sapling.old.L,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.sapling.old.L)
qqline(res.sapling.old.L)
#############

Sapling <- list( )
Sapling[[1]] <- lmer(log(bF.sapling.density+0.01) ~ (1|Site), data=bF.TNNP.old.L, REML=FALSE)
Sapling[[2]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + (1|Site), data=bF.TNNP.old.L, REML=FALSE)
Sapling[[3]] <- lmer(log(bF.sapling.density+0.01) ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.L, REML=FALSE)

##create a vector of names to trace back models in set
Sapling.names <- c("NULL","Trt","Trt*T")

##generate AICc table
print(aictab(cand.set = Sapling, modnames = Sapling.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.sapling<-matrix(nrow=3,ncol=2)
rownames(output.sapling)<-c("NULL","Trt","Trt*T");
colnames(output.sapling)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Sapling[[1]])
Rsq2<-r.squaredGLMM(Sapling[[2]])
Rsq3<-r.squaredGLMM(Sapling[[3]])

## Marginal R^2
output.sapling[1,1]<-Rsq1[1]
output.sapling[2,1]<-Rsq2[1]
output.sapling[3,1]<-Rsq3[1]

## Conditional R^2
output.sapling[1,2]<-Rsq1[2]
output.sapling[2,2]<-Rsq2[2]
output.sapling[3,2]<-Rsq3[2]

output.sapling

#########
# AICc selection of bF adult density models - MATURE
#########

# Check assumptions
Adult.mat <- lmer(bF.adult.density ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)
res.adult.mat<-resid(Adult.mat)
fit.adult.mat<-fitted(Adult.mat)
plot(fit.adult.mat,res.adult.mat)
lag.plot(res.adult.mat,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.adult.mat)
qqline(res.adult.mat)
#############

Adult <- list( )
Adult[[1]] <- lmer(bF.adult.density ~ (1|Site), data=bF.TNNP.mature, REML=FALSE)
Adult[[2]] <- lmer(bF.adult.density ~ Treatment + (1|Site), data=bF.TNNP.mature, REML=FALSE)
Adult[[3]] <- lmer(bF.adult.density ~ Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)
Adult[[4]] <- lmer(bF.adult.density ~ Treatment + Time + (1|Site), data=bF.TNNP.mature, REML=FALSE)

##create a vector of names to trace back models in set
Adult.names <- c("NULL","Trt", "T", "Trt+T")

##generate AICc table
print(aictab(cand.set = Adult, modnames = Adult.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.adult<-matrix(nrow=4,ncol=2)
rownames(output.adult)<-c("NULL","Trt", "T", "Trt+T");
colnames(output.adult)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Adult[[1]])
Rsq2<-r.squaredGLMM(Adult[[2]])
Rsq3<-r.squaredGLMM(Adult[[3]])
Rsq4<-r.squaredGLMM(Adult[[4]])

## Marginal R^2
output.adult[1,1]<-Rsq1[1]
output.adult[2,1]<-Rsq2[1]
output.adult[3,1]<-Rsq3[1]
output.adult[4,1]<-Rsq4[1]

## Conditional R^2
output.adult[1,2]<-Rsq1[2]
output.adult[2,2]<-Rsq2[2]
output.adult[3,2]<-Rsq3[2]
output.adult[4,2]<-Rsq4[2]

output.adult

#########
# AICc selection of bF adult density models - Young small gap
#########

# Check assumptions
Adult.new <- lmer(bF.adult.density ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.new, REML=FALSE)
res.adult.new<-resid(Adult.new)
fit.adult.new<-fitted(Adult.new)
plot(fit.adult.new,res.adult.new)
lag.plot(res.adult.new,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.adult.new)
qqline(res.adult.new)
#############

Adult <- list( )
Adult[[1]] <- lmer(bF.adult.density ~ (1|Site), data=bF.TNNP.new, REML=FALSE)
Adult[[2]] <- lmer(bF.adult.density ~ Treatment + (1|Site), data=bF.TNNP.new, REML=FALSE)
Adult[[3]] <- lmer(bF.adult.density ~ Time + (1|Site), data=bF.TNNP.new, REML=FALSE)
Adult[[4]] <- lmer(bF.adult.density ~ Treatment + Time + (1|Site), data=bF.TNNP.new, REML=FALSE)
Adult[[5]] <- lmer(bF.adult.density ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.new, REML=FALSE)

##create a vector of names to trace back models in set
Adult.names <- c("NULL","Trt", "T", "Trt+T", "Trt*T")

##generate AICc table
print(aictab(cand.set = Adult, modnames = Adult.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.adult<-matrix(nrow=5,ncol=2)
rownames(output.adult)<-c("NULL","Trt", "T", "Trt+T", "Trt*T");
colnames(output.adult)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Adult[[1]])
Rsq2<-r.squaredGLMM(Adult[[2]])
Rsq3<-r.squaredGLMM(Adult[[3]])
Rsq4<-r.squaredGLMM(Adult[[4]])
Rsq5<-r.squaredGLMM(Adult[[5]])

## Marginal R^2
output.adult[1,1]<-Rsq1[1]
output.adult[2,1]<-Rsq2[1]
output.adult[3,1]<-Rsq3[1]
output.adult[4,1]<-Rsq4[1]
output.adult[5,1]<-Rsq5[1]

## Conditional R^2
output.adult[1,2]<-Rsq1[2]
output.adult[2,2]<-Rsq2[2]
output.adult[3,2]<-Rsq3[2]
output.adult[4,2]<-Rsq4[2]
output.adult[5,2]<-Rsq5[2]

output.adult

#########
# AICc selection of bF adult density models - Old small gap
#########

# Check assumptions
Adult.old.M <- lmer(bF.adult.density ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)
res.adult.old.M<-resid(Adult.old.M)
fit.adult.old.M<-fitted(Adult.old.M)
plot(fit.adult.old.M,res.adult.old.M)
lag.plot(res.adult.old.M,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.adult.old.M)
qqline(res.adult.old.M)
#############

Adult <- list( )
Adult[[1]] <- lmer(bF.adult.density ~ (1|Site), data=bF.TNNP.old.M, REML=FALSE)
Adult[[2]] <- lmer(bF.adult.density ~ Treatment + (1|Site), data=bF.TNNP.old.M, REML=FALSE)
Adult[[3]] <- lmer(bF.adult.density ~ Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)
Adult[[4]] <- lmer(bF.adult.density ~ Treatment + Time + (1|Site), data=bF.TNNP.old.M, REML=FALSE)

##create a vector of names to trace back models in set
Adult.names <- c("NULL","Trt", "T", "Trt+T")

##generate AICc table
print(aictab(cand.set = Adult, modnames = Adult.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.adult<-matrix(nrow=4,ncol=2)
rownames(output.adult)<-c("NULL","Trt", "T", "Trt+T");
colnames(output.adult)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Adult[[1]])
Rsq2<-r.squaredGLMM(Adult[[2]])
Rsq3<-r.squaredGLMM(Adult[[3]])
Rsq4<-r.squaredGLMM(Adult[[4]])

## Marginal R^2
output.adult[1,1]<-Rsq1[1]
output.adult[2,1]<-Rsq2[1]
output.adult[3,1]<-Rsq3[1]
output.adult[4,1]<-Rsq4[1]

## Conditional R^2
output.adult[1,2]<-Rsq1[2]
output.adult[2,2]<-Rsq2[2]
output.adult[3,2]<-Rsq3[2]
output.adult[4,2]<-Rsq4[2]

output.adult

#########
# AICc selection of bF adult density models - Old large gap
#########

# Check assumptions
Adult.old.L <- lmer(bF.adult.density ~ Treatment + Time + Treatment*Time + (1|Site), data=bF.TNNP.old.L, REML=FALSE)
res.adult.old.L<-resid(Adult.old.L)
fit.adult.old.L<-fitted(Adult.old.L)
plot(fit.adult.old.L,res.adult.old.L)
lag.plot(res.adult.old.L,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.adult.old.L)
qqline(res.adult.old.L)
#############

Adult <- list( )
Adult[[1]] <- lmer(bF.adult.density ~ (1|Site), data=bF.TNNP.old.L, REML=FALSE)
Adult[[2]] <- lmer(bF.adult.density ~ Treatment + (1|Site), data=bF.TNNP.old.L, REML=FALSE)

##create a vector of names to trace back models in set
Adult.names <- c("NULL","Trt")

##generate AICc table
print(aictab(cand.set = Adult, modnames = Adult.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.adult<-matrix(nrow=2,ncol=2)
rownames(output.adult)<-c("NULL","Trt");
colnames(output.adult)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Adult[[1]])
Rsq2<-r.squaredGLMM(Adult[[2]])

## Marginal R^2
output.adult[1,1]<-Rsq1[1]
output.adult[2,1]<-Rsq2[1]

## Conditional R^2
output.adult[1,2]<-Rsq1[2]
output.adult[2,2]<-Rsq2[2]

output.adult
