# This R code reproduce all analyses pertaining to
# Balsam fir browsing by moose for the manuscript
# Interactive effects of spruce budworm and moose herbivory on balsam fir recruitment and regeneration

# Set your working directory
setwd("/XX/YY/ZZ")

##########################
## GRAPHICAL MODELS
##########################
# Import your data 
# Use the dataset in "bF Browsing_Exclosure experiment_TNNP_2006-2016.csv"
browse.TNNP # Name used in this code file

###
# Graphic for Balsam Fir browse proportion
# Figure 5
###

# Calculate mean of moose browse porportion
# per year, site and treatment
mean.bf.amoose.browse<-tapply(browse.TNNP$bF.browse.all.moose,list(browse.TNNP$Site,browse.TNNP$Year,browse.TNNP$Treatment),mean,na.rm=T)

par(mfrow=c(2,4),mar=c(5,2,2,1),bty="n")

plot((mean.bf.amoose.browse[4,,1]),xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,1))
points(mean.bf.amoose.browse[4,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,1))

axis(1,at=(1:11),las=2,cex.axis=1.2,labels=c(2006,"",2008,"",2010,"",
                                2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Hall's Beach")
mtext(side=3,line=0.5,"Mature")

plot((mean.bf.amoose.browse[7,,1]),xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,1))
points(mean.bf.amoose.browse[7,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,1))

axis(1,at=(1:11),las=2,cex.axis=1.2,labels=c(2006,"",2008,"",2010,"",
                                             2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Outport Trail")

plot((mean.bf.amoose.browse[5,,1]),xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,1))
points(mean.bf.amoose.browse[5,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,1))

axis(1,at=(1:11),las=2,cex.axis=1.2,labels=c(2006,"",2008,"",2010,"",
                                             2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Minchin's Cove")
mtext(side=3,line=0.5,"Young small gap")

plot((mean.bf.amoose.browse[8,,1]),xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,1))
points(mean.bf.amoose.browse[8,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,1))

axis(1,at=(1:11),las=2,cex.axis=1.2,labels=c(2006,"",2008,"",2010,"",
                                             2012,"",2014,"",2016))
mtext(side=1,line=3.5,cex=0.9,"Platter's Cove")

plot((mean.bf.amoose.browse[1,,1]),xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,1))
points(mean.bf.amoose.browse[1,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,1))

axis(1,at=(1:11),las=2,cex.axis=1.2,labels=c(2006,"",2008,"",2010,"",
                                             2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Bread Cove")
mtext(side=3,line=0.5,"Old small gap")

plot((mean.bf.amoose.browse[6,,1]),xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,1))
points(mean.bf.amoose.browse[6,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,1))

axis(1,at=(1:11),las=2,cex.axis=1.2,labels=c(2006,"",2008,"",2010,"",
                                             2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Ochre Hill")

plot((mean.bf.amoose.browse[2,,1]),xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,1))
points(mean.bf.amoose.browse[2,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,1))

axis(1,at=(1:11),las=2,cex.axis=1.2,labels=c(2006,"",2008,"",2010,"",
                                             2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Centre")
mtext(side=3,line=0.5,"Old large gap")

plot((mean.bf.amoose.browse[3,,1]),xaxt="n", xlab="",cex.axis=1.2,ylim=c(0,1))
points(mean.bf.amoose.browse[3,,2],xaxt="n", xlab="",pch = 17,cex=1.2,ylim=c(0,1))

axis(1,at=(1:11),las=2,cex.axis=1.2,labels=c(2006,"",2008,"",2010,"",
                                             2012,"",2014,"",2016))
mtext(side=1,line=3.7,cex=0.9,"Blue Hill Edge")

##########################
## UNIVARIATE ANALYSES
##########################
#To run this you need these below packages
install.packages("lme4")
library("lme4")
library(lattice)#To calculate correlation matrix
library(bbmle)
library(AICcmodavg)
library(MuMIn)

########################
# ANALYSIS ON SINGLE DISTURBANCE
########################

# Mature Forest Data
browse.mature<-subset(browse.TNNP,Site=="HAL"|Site=="OUT")

# Young small gap Data
browse.new<-subset(browse.TNNP,Site=="MIN"|Site=="PLC")

# Old small gap Data
browse.old.M<-subset(browse.TNNP,Site=="BCB"|Site=="OCH")

# Old large gap Data
browse.old.L<-subset(browse.TNNP,Site=="BHC"|Site=="BHE")

#########
# AICc selection of all moose bF browse models - MATURE
#########

# Check assumptions
bF.br.mat <- lmer(bF.browse.all.moose ~ Treatment + Time + Treatment*Time + (1|Site), data=browse.mature, REML=FALSE)
res.bF.br.mat<-resid(bF.br.mat)
fit.bF.br.mat<-fitted(bF.br.mat)
plot(fit.bF.br.mat,res.bF.br.mat)
lag.plot(res.bF.br.mat,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.bF.br.mat)
qqline(res.bF.br.mat)
#############

Browse <- list( )
Browse[[1]] <- lmer(bF.browse.all.moose ~ (1|Site), data=browse.mature, REML=FALSE)
Browse[[2]] <- lmer(bF.browse.all.moose ~ Treatment + (1|Site), data=browse.mature, REML=FALSE)
Browse[[3]] <- lmer(bF.browse.all.moose ~ Treatment + Time + Treatment*Time + (1|Site), data=browse.mature, REML=FALSE)

##create a vector of names to trace back models in set
Browse.names <- c("NULL","Trt", "Trt*T")

##generate AICc table
print(aictab(cand.set = Browse, modnames = Browse.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.browse<-matrix(nrow=3,ncol=2)
rownames(output.browse)<-c("NULL","Trt", "Trt*T");
colnames(output.browse)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Browse[[1]])
Rsq2<-r.squaredGLMM(Browse[[2]])
Rsq3<-r.squaredGLMM(Browse[[3]])

## Marginal R^2
output.browse[1,1]<-Rsq1[1]
output.browse[2,1]<-Rsq2[1]
output.browse[3,1]<-Rsq3[1]

## Conditional R^2
output.browse[1,2]<-Rsq1[2]
output.browse[2,2]<-Rsq2[2]
output.browse[3,2]<-Rsq3[2]

output.browse

#########
# AICc selection of all moose bF browse models - YOUNG SMALL GAP
#########

# Check assumptions
bF.br.new <- lmer(bF.browse.all.moose ~ Treatment + Time + Treatment*Time + (1|Site), data=browse.new, REML=FALSE)
res.bF.br.new<-resid(bF.br.new)
fit.bF.br.new<-fitted(bF.br.new)
plot(fit.bF.br.new,res.bF.br.new)
lag.plot(res.bF.br.new,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.bF.br.new)
qqline(res.bF.br.new)
#############

Browse <- list( )
Browse[[1]] <- lmer(bF.browse.all.moose ~ (1|Site), data=browse.new, REML=FALSE)
Browse[[2]] <- lmer(bF.browse.all.moose~ Treatment + (1|Site), data=browse.new, REML=FALSE)
Browse[[3]] <- lmer(bF.browse.all.moose ~ Time + (1|Site), data=browse.new, REML=FALSE)
Browse[[4]] <- lmer(bF.browse.all.moose ~ Treatment + Time + (1|Site), data=browse.new, REML=FALSE)

##create a vector of names to trace back models in set
Browse.names <- c("NULL","Trt", "T", "Trt+T")

##generate AICc table
print(aictab(cand.set = Browse, modnames = Browse.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.browse<-matrix(nrow=4,ncol=2)
rownames(output.browse)<-c("NULL","Trt", "T", "Trt+T");
colnames(output.browse)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Browse[[1]])
Rsq2<-r.squaredGLMM(Browse[[2]])
Rsq3<-r.squaredGLMM(Browse[[3]])
Rsq4<-r.squaredGLMM(Browse[[4]])

## Marginal R^2
output.browse[1,1]<-Rsq1[1]
output.browse[2,1]<-Rsq2[1]
output.browse[3,1]<-Rsq3[1]
output.browse[4,1]<-Rsq4[1]

## Conditional R^2
output.browse[1,2]<-Rsq1[2]
output.browse[2,2]<-Rsq2[2]
output.browse[3,2]<-Rsq3[2]
output.browse[4,2]<-Rsq4[2]

output.browse

#########
# AICc selection of all moose bF browse models - OLD SMALL GAP
#########

# Check assumptions
bF.br.old.M <- lmer(bF.browse.all.moose ~ Treatment + Time + Treatment*Time + (1|Site), data=browse.old.M, REML=FALSE)
res.bF.br.old.M<-resid(bF.br.old.M)
fit.bF.br.old.M<-fitted(bF.br.old.M)
plot(fit.bF.br.old.M,res.bF.br.old.M)
lag.plot(res.bF.br.old.M,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.bF.br.old.M)
qqline(res.bF.br.old.M)
#############

Browse <- list( )
Browse[[1]] <- lmer(bF.browse.all.moose ~ (1|Site), data=browse.old.M, REML=FALSE)
Browse[[2]] <- lmer(bF.browse.all.moose ~ Treatment + (1|Site), data=browse.old.M, REML=FALSE)
Browse[[3]] <- lmer(bF.browse.all.moose ~ Time + (1|Site), data=browse.old.M, REML=FALSE)
Browse[[4]] <- lmer(bF.browse.all.moose ~ Treatment + Time + (1|Site), data=browse.old.M, REML=FALSE)
Browse[[5]] <- lmer(bF.browse.all.moose ~ Treatment + Time + Treatment*Time + (1|Site), data=browse.old.M, REML=FALSE)

##create a vector of names to trace back models in set
Browse.names <- c("NULL","Trt", "T", "Trt+T", "Trt*T")

##generate AICc table
print(aictab(cand.set = Browse, modnames = Browse.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.browse<-matrix(nrow=5,ncol=2)
rownames(output.browse)<-c("NULL","Trt", "T", "Trt+T", "Trt*T");
colnames(output.browse)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Browse[[1]])
Rsq2<-r.squaredGLMM(Browse[[2]])
Rsq3<-r.squaredGLMM(Browse[[3]])
Rsq4<-r.squaredGLMM(Browse[[4]])
Rsq5<-r.squaredGLMM(Browse[[5]])

## Marginal R^2
output.browse[1,1]<-Rsq1[1]
output.browse[2,1]<-Rsq2[1]
output.browse[3,1]<-Rsq3[1]
output.browse[4,1]<-Rsq4[1]
output.browse[5,1]<-Rsq5[1]

## Conditional R^2
output.browse[1,2]<-Rsq1[2]
output.browse[2,2]<-Rsq2[2]
output.browse[3,2]<-Rsq3[2]
output.browse[4,2]<-Rsq4[2]
output.browse[5,2]<-Rsq5[2]

output.browse

#########
# AICc selection of all moose bF browse models - OLD LARGE GAP
#########

# Check assumptions
bF.br.old.L <- lmer(bF.browse.all.moose ~ Treatment + Time + Treatment*Time + (1|Site), data=browse.old.L, REML=FALSE)
res.bF.br.old.L<-resid(bF.br.old.L)
fit.bF.br.old.L<-fitted(bF.br.old.L)
plot(fit.bF.br.old.L,res.bF.br.old.L)
lag.plot(res.bF.br.old.L,
         diag=FALSE,
         do.line=FALSE)
qqnorm(res.bF.br.old.L)
qqline(res.bF.br.old.L)
#############

Browse <- list( )
Browse[[1]] <- lmer(bF.browse.all.moose ~ (1|Site), data=browse.old.L, REML=FALSE)
Browse[[2]] <- lmer(bF.browse.all.moose ~ Treatment + (1|Site), data=browse.old.L, REML=FALSE)
Browse[[3]] <- lmer(bF.browse.all.moose ~ Time + (1|Site), data=browse.old.L, REML=FALSE)
Browse[[4]] <- lmer(bF.browse.all.moose ~ Treatment + Time + (1|Site), data=browse.old.L, REML=FALSE)
Browse[[5]] <- lmer(bF.browse.all.moose ~ Treatment + Time + Treatment*Time + (1|Site), data=browse.old.L, REML=FALSE)

##create a vector of names to trace back models in set
Browse.names <- c("NULL","Trt", "T", "Trt+T", "Trt*T")

##generate AICc table
print(aictab(cand.set = Browse, modnames = Browse.names, sort = TRUE),
      digits = 3, LL = TRUE)

output.browse<-matrix(nrow=5,ncol=2)
rownames(output.browse)<-c("NULL","Trt", "T", "Trt+T", "Trt*T");
colnames(output.browse)<-c("Marginal R^2", "Conditional R^2")

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(Browse[[1]])
Rsq2<-r.squaredGLMM(Browse[[2]])
Rsq3<-r.squaredGLMM(Browse[[3]])
Rsq4<-r.squaredGLMM(Browse[[4]])
Rsq5<-r.squaredGLMM(Browse[[5]])

## Marginal R^2
output.browse[1,1]<-Rsq1[1]
output.browse[2,1]<-Rsq2[1]
output.browse[3,1]<-Rsq3[1]
output.browse[4,1]<-Rsq4[1]
output.browse[5,1]<-Rsq5[1]

## Conditional R^2
output.browse[1,2]<-Rsq1[2]
output.browse[2,2]<-Rsq2[2]
output.browse[3,2]<-Rsq3[2]
output.browse[4,2]<-Rsq4[2]
output.browse[5,2]<-Rsq5[2]

output.browse
